(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   5587942,      93162]
NotebookOptionsPosition[   5583897,      93023]
NotebookOutlinePosition[   5584902,      93058]
CellTagsIndexPosition[   5584678,      93050]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["?CustomGrid", "Input",
 CellChangeTimes->{{3.5986212312846613`*^9, 3.598621231456112*^9}}],

Cell[BoxData[
 StyleBox["\<\"CustomGrid[component, gridparameter, gridboundary, options] is \
a generic building block that models gain, absorption, or custom-defined \
actions at a surface or inside a volume within the ray-trace calculation.\\n \
\\nThe gridparameter is a user-defined variable name. When the option \
EmbedGridData->False is used, CustomGrid incorporates the gridparameter \
variable name as an input variable of the RayTraceFunction and numeric data \
points must be provided at the start of the ray-trace operation either \
through SymbolicValues setting or given directly to the RayTraceFunction. \
When the option EmbedGridData->True is used, the gridparameter data is \
embedded within the ray-trace function calculation along with the \
SymbolicValues setting for gridparameter variable and is not provided as an \
input parameter.\\n \\nThe gridboundary parameter specifies the dimensions of \
a rectangular bounding box that encloses the gridspace. The gridboundary \
parameter accepts the same types of patterns as the Boundary function.\\n \
\\nDuring a CustomGrid calculation, there are three internal function calls \
that can be invoked: GridFunction, ReportedFunction, and \
CustomDisplayFunction. CustomGrid uses the GridFunction setting to apply a \
custom-defined interaction between the gridparameter data and the traced rays \
that pass through a particular grid voxel in space. ReportedFunction is used \
to apply a final tranformation on the gridparameter data at the end of the \
ray-trace calculation. Finally, CustomDisplayFunction is an external \
tranformation passed to ManipulateSystem for rendering of the gridparameter \
data.\\n \\nSee also: GridFunction, EmbedGridData, GridOrder, GridDimensions, \
CustomDisplayFunction, ReportedFunction, and GridCoordinateOffset.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.598880593692665*^9},
 CellTags->"Info3598858993-9948643"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?GridFunction", "Input",
 CellChangeTimes->{{3.598621236070503*^9, 3.598621236266115*^9}}],

Cell[BoxData[
 StyleBox["\<\"GridFunction -> function provides a function that determines \
the gain, absorption, and other custom behaviors for each element within a \
predefined grid space within an optical component during a ray-trace \
calculation.\\n \\nThe input parameter to the gain function is given 10 \
parameters although not all parameters need be employed by the function. For \
three-dimensional grid functions, the first three parameters are indices to \
the affected gain grid element. For two-dimensional grid functions, the first \
two parameters are indices to the affected gain grid element. For \
one-dimensional grid functions, the first parameter is an index to the \
affected gain grid element. The next parameter is the distance of the ray \
traversing across the gird element. The remaining 6 parameters are the \
starting and ending coordinates of the ray that passes through a given grid \
element volume. In addition, the gain function may also reference any number \
of internal ray-parameters such as RayStart, RayEnd, Intensity, RayLength, \
WaveLength, and Polarization. The grid function may change any ray parameter \
as well as the gridparameter name originally specified with the CustomGrid \
function. Any changed Ray parameter element such as Intensity or the \
gridparameter parameter will be used for the subsequent ray-gain grid \
interactions.\\n \\nSee also: CustomGrid, EmbedGridData, GridOrder, \
GridDimensions, CustomDisplayFunction, ReportedFunction, and \
GridCoordinateOffset.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.598880596104759*^9},
 CellTags->"Info3598858995-9948643"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?CustomDisplayFunction", "Input",
 CellChangeTimes->{{3.598879025202054*^9, 3.5988790318377*^9}}],

Cell[BoxData[
 StyleBox["\<\"CustomDisplayFunction -> Function[datatransformation] to \
applies a functional transformation on datasets within ManipulateSystem for \
the rendering of the dataset.\\n \\nMost often, the dataset is result of a \
ray-trace calculation that includes CustomGrid. In some cases, the \
datatransformation takes a one-dimensional dataset and transforms the data \
into a higher-dimensional dataset. An example of this use would be \
CustomDisplayFunction -> Function[Partition[Partition[#,10],10]].\\n \\nIn \
other cases, a higher-dimensional dataset is reduced into a simplified lower \
dimensional subdataset, such as to render a planar cross-section of \
volumetric data. An example of this would be CustomDisplayFunction -> \
Function[#[[5]]]. By default, CustomDisplayFunction -> Function[#] is used. \
CustomDisplayFunction is not embedded within the ray-trace function code but \
is instead called by ManipulateSystem as an external function immediately \
prior to the rendering operation by graphics operations such as ListPlot, \
ListDensityPlot, ListContourPlot, and ListPlot3D. Otherwise, ReportedFunction \
is used to embed the data transformation directly within the ray-trace \
function code.\\n \\nSee also: CustomGrid, EmbedGridData, \
GridCoordinateOffset, GridDimensions, CustomDisplayFunction, \
ReportedFunction, GridFunction, GridOrder, and ManipulateSystem.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.598881511957151*^9},
 CellTags->"Info3598859911-8864466"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?SlabPrism", "Input",
 CellChangeTimes->{{3.598708907471446*^9, 3.598708909778322*^9}}],

Cell[BoxData[
 StyleBox["\<\"SlabPrism[boundaryparameters, label, options] designates a \
rectangular refractive box. \\n \\nHere, the user-named label parameter is \
optional and can be omitted. When it is present, its text content is used to \
identify the object in both the rendered graphics and the output cell \
expression. There are five methods for specifying boundaryparameters: \
SlabPrism[{x1, y1, z1}, {x2, y2, z2}] uses the coordinates of top and bottom \
opposite corners of a rectangular box, SlabPrism[side] assumes a cube \
boundary, SlabPrism[xside, yside, zside] assumes a three-dimensional box that \
has a length specified by xside, a width specified by yside, and a height \
specified by zside, and SlabPrism[aside, bside] assumes a three-dimensional \
box that has a length specified by aside, a width specified by bside, and a \
height specified by bside. SlabPrism[angle, length, width, height] specifies \
angular tilts for the two facets that cross the optical (x) axis.  \
SlabPrism[angle1, angle2, length, width, height] specifies independent \
angular tilts for the two opposite facets that cross the optical (x) \
axis.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.59887903549224*^9},
 CellTags->"Info3598857435-2171160"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[CustomGrid]", "Input",
 CellChangeTimes->{{3.598723348499531*^9, 3.598723349597268*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TakeFrom", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"CreatedRay", ",", "OriginalRay", ",", "ChangedSurface"}], 
     "}"}]}], ",", 
   RowBox[{"AddTo", "\[Rule]", 
    RowBox[{"{", "CreatedRay", "}"}]}], ",", 
   RowBox[{"GridCoordinateOffset", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.1`", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"SurfaceID", "\[Rule]", "False"}], ",", 
   RowBox[{"RunningCommentary", "\[Rule]", "False"}], ",", 
   RowBox[{"SymbolicValues", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"EmbedGridData", "\[Rule]", "False"}], ",", 
   RowBox[{"GridOrder", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"GridDimensions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
   RowBox[{"GridFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.59872334994182*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Original Example with ListPlot3D\
\>", "Section",
 CellChangeTimes->{{3.598877088109701*^9, 3.598877116902734*^9}}],

Cell[CellGroupData[{

Cell["\<\
gainslab = CustomGrid[SlabPrism[10], griddata, 9, \
SymbolicValues->{griddata->{Table[0.,{30},{30}]},absorp->0.1},
\tGridFunction->Function[griddata[[#3,#2,#1]]=griddata[[#3,#2,#1]]+Intensity*\
Exp[#4*absorp];Intensity = Intensity*Exp[-#4*absorp]], 
\t\tEmbedGridData->True, ReportedFunction->Hold[griddata[[1]]]]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.598018682495386*^9, 
   3.598018685071406*^9}, {3.5983586945572042`*^9, 3.5983587019643383`*^9}, {
   3.5986167063493357`*^9, 3.598616708300345*^9}, {3.598616749468322*^9, 
   3.598616781307159*^9}, {3.598616822165442*^9, 3.598616905136224*^9}, {
   3.59861694510306*^9, 3.5986170016457233`*^9}, {3.598617139222601*^9, 
   3.598617172014608*^9}, {3.598617685355007*^9, 3.598617707574271*^9}, {
   3.598617770991014*^9, 3.598617773188614*^9}, {3.5986178250202436`*^9, 
   3.598617990576351*^9}, {3.598618023555862*^9, 3.5986180278039827`*^9}, {
   3.598618096492874*^9, 3.598618104916382*^9}, {3.598618152205185*^9, 
   3.598618265855753*^9}, {3.598618297071982*^9, 3.5986183010146933`*^9}, {
   3.598618331216523*^9, 3.598618331831071*^9}, {3.5986183899972353`*^9, 
   3.598618421563044*^9}, {3.5986185009868507`*^9, 3.5986185068896914`*^9}, {
   3.598618653682613*^9, 3.59861868614471*^9}, {3.598618738921391*^9, 
   3.598618743985243*^9}, 3.5986188285199137`*^9, {3.598618866776342*^9, 
   3.598618867838866*^9}, {3.5986190004339447`*^9, 3.598619028792245*^9}, {
   3.598619362025923*^9, 3.598619365008605*^9}, {3.5986197342580957`*^9, 
   3.598619747121016*^9}, {3.598619955573572*^9, 3.598619962068234*^9}, 
   3.598620032682416*^9, {3.598620156507202*^9, 3.598620164738914*^9}, 
   3.598621062515483*^9, {3.598712813840581*^9, 3.5987128184058523`*^9}, 
   3.598713443321837*^9, {3.598723011077673*^9, 3.598723035051834*^9}, {
   3.5987231973758802`*^9, 3.598723221719447*^9}, {3.5987233556133137`*^9, 
   3.5987233737716017`*^9}, {3.598723669213241*^9, 3.598723676413336*^9}, 
   3.598724248577115*^9, {3.598783578389386*^9, 3.5987835915787992`*^9}, 
   3.598785013378652*^9, {3.5987852234833927`*^9, 3.5987852260575533`*^9}, {
   3.598785463616057*^9, 3.598785495357689*^9}, {3.5987874460655518`*^9, 
   3.598787446568397*^9}, {3.598787518012682*^9, 3.598787518459611*^9}, {
   3.598789641944824*^9, 3.598789646592228*^9}, {3.598790214801388*^9, 
   3.5987902163291597`*^9}, {3.598793356375049*^9, 3.598793367167121*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"SlabPrism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "5"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", "griddata", 
      ",", "9", ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"absorp", "\[Rule]", "0.1`"}], "}"}]}], ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"griddata", "\[LeftDoubleBracket]", 
             RowBox[{"#3", ",", "#2", ",", "#1"}], "\[RightDoubleBracket]"}], 
            "=", 
            RowBox[{
             RowBox[{"griddata", "\[LeftDoubleBracket]", 
              RowBox[{"#3", ",", "#2", ",", "#1"}], "\[RightDoubleBracket]"}],
              "+", 
             RowBox[{"Intensity", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"#4", " ", "absorp"}], "]"}]}]}]}], ";", 
           RowBox[{"Intensity", "=", 
            RowBox[{"Intensity", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", "#4"}], " ", "absorp"}], "]"}]}]}]}], ")"}], 
         "&"}], ")"}]}], ",", 
      RowBox[{"EmbedGridData", "\[Rule]", "True"}], ",", 
      RowBox[{"ReportedFunction", "\[Rule]", 
       RowBox[{"Hold", "[", 
        RowBox[{
        "griddata", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "]"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.598785481720141*^9, 3.598787447680771*^9, 3.598787519332398*^9, 
   3.598787787438519*^9, 3.5987893991684237`*^9, {3.598789638608594*^9, 
   3.5987896476037273`*^9}, 3.598789730546843*^9, 3.5987902174790277`*^9, 
   3.598793372623831*^9, 3.5988810484489183`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[LineOfRays[3,NumberOfRays->11],{{xzs,0},{yzs,0.}},{\
tzhs,0}],Resonate[{Move[SlabPrism[10],5],Move[Mirror[{10,10}],16,{szangle,5}]}\
],Boundary[20]},
\t{DynamicFrame[PlotType->TopView],
\tDynamicFrame[PlotType->ListPlot3D,PlotLabel->\"Absorption\",PlotRange->{0,\
All},AspectRatio->1,
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Resonate[{Move[gainslab,5],Move[\
Mirror[{10,10}],16,{szangle,5}]}],Boundary[20]}],
\tDynamicFrame[PlotType->ListPlot3D,PlotLabel->\"No \
Mirror\",PlotRange->{0,All},AspectRatio->1,
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Move[gainslab,5],Boundary[20]}]},\
ArrangeSystem->False]\
\>", "Input",
 CellChangeTimes->{{3.59861907189555*^9, 3.59861907603083*^9}, {
   3.5986192376173153`*^9, 3.598619243843154*^9}, {3.598619323601527*^9, 
   3.598619326269944*^9}, {3.5986195567035427`*^9, 3.598619644024191*^9}, {
   3.598619848748253*^9, 3.5986198511948767`*^9}, {3.5986200267348623`*^9, 
   3.598620132315246*^9}, {3.598620263843527*^9, 3.598620286210291*^9}, {
   3.5986205657846117`*^9, 3.598620683654751*^9}, {3.598620715446212*^9, 
   3.598620768892735*^9}, 3.598620803614503*^9, 3.5986208399808807`*^9, {
   3.598709580833399*^9, 3.598709610655719*^9}, {3.598713614035285*^9, 
   3.598713641162293*^9}, {3.5987228963934937`*^9, 3.5987229059525223`*^9}, {
   3.598722963206867*^9, 3.59872297836563*^9}, {3.598723162145793*^9, 
   3.59872318311202*^9}, {3.598724182448244*^9, 3.598724206824198*^9}, {
   3.5987834755754137`*^9, 3.5987835172368917`*^9}, 3.598783553775072*^9, {
   3.598783648841077*^9, 3.598783729877985*^9}, {3.59878378137654*^9, 
   3.5987838738456306`*^9}, {3.598783914606614*^9, 3.598783927916171*^9}, {
   3.598783992597123*^9, 3.598784058120701*^9}, {3.598784090552135*^9, 
   3.598784098287863*^9}, 3.598784350306773*^9, {3.59878464861152*^9, 
   3.598784690963435*^9}, {3.598784967972073*^9, 3.598784971546756*^9}, {
   3.598785061601509*^9, 3.5987850667629747`*^9}, {3.598789962290284*^9, 
   3.598790000126421*^9}, {3.598790208027376*^9, 3.598790210265657*^9}, {
   3.598877659498846*^9, 3.59887766118296*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`absorp$$ = 
    0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
    0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {0.5, 
    0.}, $CellContext`laststartposszangle$$ = {
    16., 0}, $CellContext`laststartpostzhs$$ = {0., 
    0.}, $CellContext`lastszangle$$ = 5., $CellContext`lasttzhs$$ = 
    0., $CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
    185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
    10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
    0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = -180., \
$CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
    0.5, $CellContext`staticpolygons11174572014116111057299129$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
      
      "]]}, $CellContext`staticpolygons12174572014116111057300123$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons13174572014116111057301385$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
      "]]}, $CellContext`szangle$$ = 
    5., $CellContext`tzhs$$ = 0., $CellContext`xoffszangle$$ = 
    0.4980973490458728, $CellContext`xofftzhs$$ = 
    0.5, $CellContext`xszangle$$ = 16.498097349045874`, $CellContext`xtzhs$$ =
     0.5, $CellContext`xzs$$ = 0., $CellContext`yoffszangle$$ = 
    0.04357787137382908, $CellContext`yofftzhs$$ = 
    0., $CellContext`yszangle$$ = 0.04357787137382908, $CellContext`ytzhs$$ = 
    0., $CellContext`yzs$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`tzhs$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`xzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`szangle$$], 5.}, -175., 185.}, {{
       Hold[$CellContext`absorp$$], 0.1}, 0.001, 0.2}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Style[
        Grid[{{"absorp", 
           InputField[
            Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159317457201411611117873350; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
             Dynamic[$CellContext`minabsorp$$], 
             Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159317457201411611117873350; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "tzhs", "xzs", "yzs", "szangle", 
               "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xtzhs$$], 0.5}}, {{
       Hold[$CellContext`ytzhs$$], 0.}}, {{
       Hold[$CellContext`radiustzhs$$], 0.5}}, {{
       Hold[$CellContext`xofftzhs$$], 0.5}}, {{
       Hold[$CellContext`yofftzhs$$], 0.}}, {{
       Hold[$CellContext`laststartpostzhs$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpostzhs$$], {0.5, 0.}}}, {{
       Hold[$CellContext`lasttzhs$$], 0}}, {{
       Hold[$CellContext`xszangle$$], 16.498097349045874`}}, {{
       Hold[$CellContext`yszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`radiusszangle$$], 0.5}}, {{
       Hold[$CellContext`xoffszangle$$], 0.4980973490458728}}, {{
       Hold[$CellContext`yoffszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`laststartposszangle$$], {16., 0}}}, {{
       Hold[$CellContext`lastlocposszangle$$], {16.498097349045874`, 
       0.04357787137382908}}}, {{
       Hold[$CellContext`lastszangle$$], 0}}, {{
       Hold[$CellContext`staticpolygons11174572014116111057299129$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons12174572014116111057300123$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons13174572014116111057301385$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
         "]]}}}}, Typeset`size$$ = {
    816., {433.625, 439.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`tzhs$58168$$ = 
    0, $CellContext`xzs$58173$$ = 0, $CellContext`yzs$58174$$ = 
    0, $CellContext`szangle$58175$$ = 0, $CellContext`absorp$58176$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`absorp$$ = 
        0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
         0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {0.5, 
         0.}, $CellContext`laststartposszangle$$ = {
         16., 0}, $CellContext`laststartpostzhs$$ = {0., 
         0.}, $CellContext`lastszangle$$ = 0, $CellContext`lasttzhs$$ = 
        0, $CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
        185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
        10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
        0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = \
-180., $CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
        0.5, $CellContext`staticpolygons11174572014116111057299129$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
           
           "]]}, $CellContext`staticpolygons12174572014116111057300123$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons13174572014116111057301385$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
           
           "]]}, $CellContext`szangle$$ = 5., $CellContext`tzhs$$ = 
        0., $CellContext`xoffszangle$$ = 
        0.4980973490458728, $CellContext`xofftzhs$$ = 
        0.5, $CellContext`xszangle$$ = 
        16.498097349045874`, $CellContext`xtzhs$$ = 0.5, $CellContext`xzs$$ = 
        0., $CellContext`yoffszangle$$ = 
        0.04357787137382908, $CellContext`yofftzhs$$ = 
        0., $CellContext`yszangle$$ = 
        0.04357787137382908, $CellContext`ytzhs$$ = 0., $CellContext`yzs$$ = 
        0.}, "ControllerVariables" :> {
        Hold[$CellContext`tzhs$$, $CellContext`tzhs$58168$$, 0], 
        Hold[$CellContext`xzs$$, $CellContext`xzs$58173$$, 0], 
        Hold[$CellContext`yzs$$, $CellContext`yzs$58174$$, 0], 
        Hold[$CellContext`szangle$$, $CellContext`szangle$58175$$, 0], 
        Hold[$CellContext`absorp$$, $CellContext`absorp$58176$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[
                 0.8], $CellContext`staticpolygons11174572014116111057299129$$\
, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons12174572014116111057300123$$, 
                  Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`szangle$$], -
                    Sin[Degree $CellContext`szangle$$]}, {
                    Sin[Degree $CellContext`szangle$$], 
                    Cos[Degree $CellContext`szangle$$]}}, {
                    16., 0}}]], \
$CellContext`staticpolygons13174572014116111057301385$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction1174572014116111057304455[$\
CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$], And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]],
                     TrackedSymbols :> {$CellContext`tzhs$$, \
$CellContext`xzs$$, $CellContext`yzs$$, $CellContext`szangle$$}], 
                   SynchronousUpdating -> False]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[If[
                    
                    Or[$CellContext`laststartpostzhs$$ != \
{$CellContext`xzs$$, $CellContext`yzs$$}, $CellContext`lasttzhs$$ =!= \
$CellContext`tzhs$$], $CellContext`laststartpostzhs$$ = {$CellContext`xzs$$, \
$CellContext`yzs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`laststartpostzhs$$, \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$}}, \
({$CellContext`laststartpostzhs$$, {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xtzhs$$, $CellContext`ytzhs$$} != \
$CellContext`lastlocpostzhs$$, $CellContext`lasttzhs$$ != \
$CellContext`tzhs$$], $CellContext`lastlocpostzhs$$ = {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$}), \
({$CellContext`xtzhs$$, $CellContext`ytzhs$$} = #; $CellContext`xofftzhs$$ = \
$CellContext`xtzhs$$ - $CellContext`xzs$$; $CellContext`yofftzhs$$ = \
$CellContext`ytzhs$$ - $CellContext`yzs$$; $CellContext`radiustzhs$$ = 
                    Sqrt[$CellContext`xofftzhs$$^2 + \
$CellContext`yofftzhs$$^2]; $CellContext`tzhs$$ = 
                    Chop[ArcTan[$CellContext`xofftzhs$$, \
$CellContext`yofftzhs$$]/
                    Degree]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["tzhs = ", 
                    ToString[$CellContext`tzhs$$]]]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[
                  If[$CellContext`lastszangle$$ =!= $CellContext`szangle$$, \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`laststartposszangle$$, \
{$CellContext`xszangle$$, $CellContext`yszangle$$}}, \
({$CellContext`laststartposszangle$$, {$CellContext`xszangle$$, \
$CellContext`yszangle$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xszangle$$, $CellContext`yszangle$$} != \
$CellContext`lastlocposszangle$$, $CellContext`lastszangle$$ != \
$CellContext`szangle$$], $CellContext`lastlocposszangle$$ = \
{$CellContext`xszangle$$, $CellContext`yszangle$$}; \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$}), ({$CellContext`xszangle$$, \
$CellContext`yszangle$$} = #; $CellContext`xoffszangle$$ = \
$CellContext`xszangle$$ - 
                    16.; $CellContext`yoffszangle$$ = $CellContext`yszangle$$ + 
                    0; $CellContext`radiusszangle$$ = 
                    Sqrt[$CellContext`xoffszangle$$^2 + \
$CellContext`yoffszangle$$^2]; $CellContext`szangle$$ = 
                    Chop[ArcTan[$CellContext`xoffszangle$$, \
$CellContext`yoffszangle$$]/
                    Degree]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["szangle = ", 
                    ToString[$CellContext`szangle$$]]]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xzs$$, $CellContext`yzs$$}, \
({$CellContext`xzs$$, $CellContext`yzs$$} = Chop[#])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["{xzs, yzs} = ", 
                    ToString[
                    Chop[{$CellContext`xzs$$, $CellContext`yzs$$}]]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "Absorption" -> Dynamic[
             ListPlot3D[
              
              Apply[$CellContext`rayfunction217457201411611113965897, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$, $CellContext`absorp$$}], {
              PlotLabel -> "Absorption", PlotRange -> {0, All}, AspectRatio -> 
               1, DataRange -> {{0, 9}, {(-9)/2, 9/2}}, Axes -> True, Mesh -> 
               False, ImageSize -> 800}], SynchronousUpdating -> True], 
           "No Mirror" -> Dynamic[
             ListPlot3D[
              
              Apply[$CellContext`rayfunction317457201411611117862313, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`absorp$$}], {
              PlotLabel -> "No Mirror", PlotRange -> {0, All}, AspectRatio -> 
               1, DataRange -> {{0, 9}, {(-9)/2, 9/2}}, Axes -> True, Mesh -> 
               False, ImageSize -> 800}], SynchronousUpdating -> True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`tzhs$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`xzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`yzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`szangle$$, 5.}, -175., 185., 
         ControlType -> None}, {{$CellContext`absorp$$, 0.1}, 0.001, 0.2, 
         ControlType -> None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Style[
         Grid[{{"absorp", 
            InputField[
             Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159317457201411611117873350; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
              Dynamic[$CellContext`minabsorp$$], 
              Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159317457201411611117873350; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]], {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "tzhs", "xzs", "yzs", "szangle", 
                   "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xtzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`ytzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiustzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xofftzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`yofftzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpostzhs$$, {0., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocpostzhs$$, {0.5, 0.}}, ControlType -> 
         None}, {{$CellContext`lasttzhs$$, 0}, ControlType -> 
         None}, {{$CellContext`xszangle$$, 16.498097349045874`}, ControlType -> 
         None}, {{$CellContext`yszangle$$, 0.04357787137382908}, ControlType -> 
         None}, {{$CellContext`radiusszangle$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xoffszangle$$, 0.4980973490458728}, 
         ControlType -> 
         None}, {{$CellContext`yoffszangle$$, 0.04357787137382908}, 
         ControlType -> 
         None}, {{$CellContext`laststartposszangle$$, {16., 0}}, ControlType -> 
         None}, {{$CellContext`lastlocposszangle$$, {16.498097349045874`, 
          0.04357787137382908}}, ControlType -> 
         None}, {{$CellContext`lastszangle$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons11174572014116111057299129$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons12174572014116111057300123$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons13174572014116111057301385$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5}, SynchronousInitialization -> 
        False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {495., 500.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction1174572014116111057304455 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukgHN/HY
kouu2+H6nigFd0kx4jKHkPlQcO61AwoN16eGxife3egixmDwGSPcsIsP1XBj
gNJqaHzi3Y0ucgYM3mCEG3bxoRpuHFBaDY1PvLvRRYzA6eoxRrhhFx+q4SYA
pdXQ+MS7G13EABw+lzHCDbv4UA03ESithsYn3t3YxTfYECc+VMNNAkqrofGJ
dze6iAUkXREpPlTDTQZKq6HxiXc3uggkfB4TKT5Uw00BSquh8Yl3N7rIBUi9
SaT4UA03JSithsYn3t3oIiaQdhqR4kM13FSgtBoan3h3o4swgckfRIoP1XBT
w0ET724YCwBYfDdD
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$93}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$93 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$93), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$93, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$93}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 56973.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$94}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$94 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$94), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$94, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$94}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57001.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$97}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$97 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$97), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$97, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$97}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57085.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$98}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$98 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$98), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$98, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$98}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57113.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$96}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$96 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$96), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$96, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$96}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57057.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$95}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$95 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$95), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$95, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$95}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57029.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$101}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$101 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$101), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$101, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$101}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57165.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    56973.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    57001.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    57085.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    57113.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    57057.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    57029.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    57165.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$102}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$102 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$102), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$102, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$102}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57319.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$105}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$105 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$105), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$105, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$105}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57320.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$102}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$102 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$102), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$102, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$102}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57321.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$105}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$105 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$105), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$105, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$105}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57322.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$104}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$104 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$104), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$104, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$104}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57323.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$104}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$104 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$104), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$104, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$104}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57324.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    57319.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    57320.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    57321.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    57322.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    57323.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    57324.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction217457201411611113965897 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwzEJACAABMAXewhWMoLgbP9NB1t4B9fnHqsmKXd7AQAAAAAAgH8c+ScB
6g==
             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3GV0kwkTwPvgxYMXT7EtHqBAseXBiwdvoUCAAoWFJVgp/lCsePDiwYsH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                
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$82}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$82 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$82), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$82, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$82}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52335.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$83}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$83 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$83), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$83, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$83}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52363.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$91}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$91 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$91), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$91, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$91}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52447.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$92}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$92 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$92), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$92, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$92}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52475.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$87}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$87 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$87), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$87, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$87}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52419.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$84}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$84 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$84), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$84, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$84}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52391.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$107}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$107 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$107), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$107, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$107}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57358.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    52335.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    52363.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    
                    52447.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    52475.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    52419.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    52391.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    57358.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$110}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$110 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$110), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$110, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$110}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57512.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$113}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$113 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$113), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$113, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$113}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57513.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$110}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$110 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$110), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$110, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$110}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57514.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$113}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$113 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$113), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$113, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$113}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57515.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$111}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$111 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$111), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$111, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$111}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57516.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$111}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$111 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$111), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$111, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$111}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57517.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    57512.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    57513.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    57514.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    57515.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    57516.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    57517.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Part[$CellContext`griddata$, 
             1]], $CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction317457201411611117862313 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwzEJACAABMAXewhWMoLgbP9NB1t4B9fnHqsmKXd7AQAAAAAAgH8c+ScB
6g==
             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3GdUkwvT6P1YUOyxY48deyxbsceOPXbsERv2qKhYtl5iwx47VmJHRY0d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                
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$82}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$82 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$82), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$82, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$82}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52335.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$83}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$83 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$83), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$83, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$83}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52363.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$91}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$91 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$91), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$91, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$91}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52447.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$92}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$92 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$92), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$92, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$92}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52475.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$87}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$87 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$87), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$87, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$87}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52419.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$84}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$84 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$84), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$84, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$84}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 52391.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    52335.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    52363.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    52447.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    52475.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    52419.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    52391.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    52529, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52335, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52363, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52447, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52475, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    52419, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$115}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$115 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$115), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$115, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$115}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57620.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$118}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$118 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$118), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$118, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$118}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57621.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$115}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$115 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$115), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$115, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$115}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57622.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$118}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$118 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$118), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$118, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$118}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57623.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$117}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$117 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$117), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$117, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$117}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57624.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$117}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$117 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$117), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$117, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$117}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 57625.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    57620.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    57621.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    57622.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    57623.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    57624.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    57625.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Part[$CellContext`griddata$, 
             1]], $CellContext`compileoptionsetting$]]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.598784710275069*^9, 3.59878496313083*^9, {3.5987849947231693`*^9, 
   3.598785000704669*^9}, {3.5987850368587513`*^9, 3.598785053676084*^9}, {
   3.598785086243341*^9, 3.5987851517978086`*^9}, 3.598785247088231*^9, 
   3.598785279965413*^9, 3.598785455409631*^9, {3.598785502880865*^9, 
   3.598785505264822*^9}, 3.598789668905858*^9, {3.598789753546463*^9, 
   3.598789759579892*^9}, {3.598789792682342*^9, 3.5987899428663054`*^9}, {
   3.598790046172325*^9, 3.5987901348831177`*^9}, {3.598790190402524*^9, 
   3.5987902026919727`*^9}, {3.598790239637553*^9, 3.598790251319952*^9}, {
   3.598790283579562*^9, 3.59879028516055*^9}, {3.598790385231908*^9, 
   3.598790405741469*^9}, {3.5987904881591187`*^9, 3.598790520706761*^9}, {
   3.5987909178850803`*^9, 3.598790930577498*^9}, {3.598790972766377*^9, 
   3.598791013745255*^9}, {3.598791052676559*^9, 3.5987910831958847`*^9}, {
   3.5987933976718187`*^9, 3.598793413178116*^9}, {3.598793875645924*^9, 
   3.598793878505085*^9}, {3.598794200133984*^9, 3.59879421701481*^9}, {
   3.598877065882835*^9, 3.5988770672518187`*^9}, 3.5988775961841803`*^9, 
   3.598881071262055*^9, 3.614739149910006*^9, {3.614739206182493*^9, 
   3.614739223231142*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Original Example with ListDensityPlot\
\>", "Section",
 CellChangeTimes->{{3.598877088109701*^9, 3.598877116902734*^9}, 
   3.5988771485976543`*^9}],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[LineOfRays[3,NumberOfRays->11],{{xzs,0},{yzs,0.}},{\
tzhs,0}],Resonate[{Move[SlabPrism[10],5],Move[Mirror[{10,10}],16,{szangle,5}]}\
],Boundary[20]},
\t{DynamicFrame[PlotType->TopView],
\tDynamicFrame[PlotType->ListDensityPlot,PlotLabel->\"Absorption\",PlotRange->\
{0,All},AspectRatio->1,
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Resonate[{Move[gainslab,5],Move[\
Mirror[{10,10}],16,{szangle,5}]}],Boundary[20]}],
\tDynamicFrame[PlotType->ListDensityPlot,PlotLabel->\"No \
Mirror\",PlotRange->{0,All},AspectRatio->1,
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Move[gainslab,5],Boundary[20]}]},
\t\tArrangeSystem->False]\
\>", "Input",
 CellChangeTimes->{{3.59861907189555*^9, 3.59861907603083*^9}, {
   3.5986192376173153`*^9, 3.598619243843154*^9}, {3.598619323601527*^9, 
   3.598619326269944*^9}, {3.5986195567035427`*^9, 3.598619644024191*^9}, {
   3.598619848748253*^9, 3.5986198511948767`*^9}, {3.5986200267348623`*^9, 
   3.598620132315246*^9}, {3.598620263843527*^9, 3.598620286210291*^9}, {
   3.5986205657846117`*^9, 3.598620683654751*^9}, {3.598620715446212*^9, 
   3.598620768892735*^9}, 3.598620803614503*^9, 3.5986208399808807`*^9, {
   3.598709580833399*^9, 3.598709610655719*^9}, {3.598713614035285*^9, 
   3.598713641162293*^9}, {3.5987228963934937`*^9, 3.5987229059525223`*^9}, {
   3.598722963206867*^9, 3.59872297836563*^9}, {3.598723162145793*^9, 
   3.59872318311202*^9}, {3.598724182448244*^9, 3.598724206824198*^9}, {
   3.5987834755754137`*^9, 3.5987835172368917`*^9}, 3.598783553775072*^9, {
   3.598783648841077*^9, 3.598783729877985*^9}, {3.59878378137654*^9, 
   3.5987838738456306`*^9}, {3.598783914606614*^9, 3.598783927916171*^9}, {
   3.598783992597123*^9, 3.598784058120701*^9}, {3.598784090552135*^9, 
   3.598784098287863*^9}, 3.598784350306773*^9, {3.59878464861152*^9, 
   3.598784690963435*^9}, {3.598784967972073*^9, 3.598784971546756*^9}, {
   3.598785061601509*^9, 3.5987850667629747`*^9}, 3.598785250373899*^9, {
   3.598785470303138*^9, 3.5987854772250557`*^9}, {3.598785607858865*^9, 
   3.5987856207812366`*^9}, {3.598786264539584*^9, 3.598786275512472*^9}, {
   3.5987863706017427`*^9, 3.5987863788811293`*^9}, 3.598787400746312*^9, {
   3.598787610601501*^9, 3.5987876725749397`*^9}, {3.59878770352676*^9, 
   3.598787716038309*^9}, 3.598789462693212*^9, {3.598790343641533*^9, 
   3.59879034559137*^9}, {3.598877652344132*^9, 3.5988776541511173`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`absorp$$ = 
    0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
    0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {6.49636671490405, 
    1.3772505345223234`}, $CellContext`laststartposszangle$$ = {
    16., 0}, $CellContext`laststartpostzhs$$ = {3.3924037533896563`, 
    1.807781373852734}, $CellContext`lastszangle$$ = 
    5., $CellContext`lasttzhs$$ = -7.896747124002901, \
$CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
    185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
    10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
    0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = -180., \
$CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
    3.133678807738239, \
$CellContext`staticpolygons11168982014115105024113498$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
      
      "]]}, $CellContext`staticpolygons12168982014115105024114986$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons13168982014115105024116296$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
      "]]}, $CellContext`szangle$$ = 
    5., $CellContext`tzhs$$ = -7.896747124002901, $CellContext`xoffszangle$$ =
     0.4980973490458728, $CellContext`xofftzhs$$ = 
    3.1039629615143935`, $CellContext`xszangle$$ = 
    16.498097349045874`, $CellContext`xtzhs$$ = 
    6.49636671490405, $CellContext`xzs$$ = 
    3.3924037533896563`, $CellContext`yoffszangle$$ = 
    0.04357787137382908, $CellContext`yofftzhs$$ = -0.4305308393304106, \
$CellContext`yszangle$$ = 0.04357787137382908, $CellContext`ytzhs$$ = 
    1.3772505345223234`, $CellContext`yzs$$ = 1.807781373852734, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`tzhs$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`xzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`szangle$$], 5.}, -175., 185.}, {{
       Hold[$CellContext`absorp$$], 0.1}, 0.001, 0.2}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Style[
        Grid[{{"absorp", 
           InputField[
            Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable1593168982014115105034996411; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
             Dynamic[$CellContext`minabsorp$$], 
             Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable1593168982014115105034996411; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "tzhs", "xzs", "yzs", "szangle", 
               "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xtzhs$$], 0.5}}, {{
       Hold[$CellContext`ytzhs$$], 0.}}, {{
       Hold[$CellContext`radiustzhs$$], 0.5}}, {{
       Hold[$CellContext`xofftzhs$$], 0.5}}, {{
       Hold[$CellContext`yofftzhs$$], 0.}}, {{
       Hold[$CellContext`laststartpostzhs$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpostzhs$$], {0.5, 0.}}}, {{
       Hold[$CellContext`lasttzhs$$], 0}}, {{
       Hold[$CellContext`xszangle$$], 16.498097349045874`}}, {{
       Hold[$CellContext`yszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`radiusszangle$$], 0.5}}, {{
       Hold[$CellContext`xoffszangle$$], 0.4980973490458728}}, {{
       Hold[$CellContext`yoffszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`laststartposszangle$$], {16., 0}}}, {{
       Hold[$CellContext`lastlocposszangle$$], {16.498097349045874`, 
       0.04357787137382908}}}, {{
       Hold[$CellContext`lastszangle$$], 0}}, {{
       Hold[$CellContext`staticpolygons11168982014115105024113498$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons12168982014115105024114986$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons13168982014115105024116296$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
         "]]}}}}, Typeset`size$$ = {
    816., {433.625, 439.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`tzhs$259950$$ = 
    0, $CellContext`xzs$259951$$ = 0, $CellContext`yzs$259952$$ = 
    0, $CellContext`szangle$259953$$ = 0, $CellContext`absorp$259954$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`absorp$$ = 
        0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
         0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {0.5, 
         0.}, $CellContext`laststartposszangle$$ = {
         16., 0}, $CellContext`laststartpostzhs$$ = {0., 
         0.}, $CellContext`lastszangle$$ = 0, $CellContext`lasttzhs$$ = 
        0, $CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
        185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
        10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
        0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = \
-180., $CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
        0.5, $CellContext`staticpolygons11168982014115105024113498$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
           
           "]]}, $CellContext`staticpolygons12168982014115105024114986$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons13168982014115105024116296$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
           
           "]]}, $CellContext`szangle$$ = 5., $CellContext`tzhs$$ = 
        0., $CellContext`xoffszangle$$ = 
        0.4980973490458728, $CellContext`xofftzhs$$ = 
        0.5, $CellContext`xszangle$$ = 
        16.498097349045874`, $CellContext`xtzhs$$ = 0.5, $CellContext`xzs$$ = 
        0., $CellContext`yoffszangle$$ = 
        0.04357787137382908, $CellContext`yofftzhs$$ = 
        0., $CellContext`yszangle$$ = 
        0.04357787137382908, $CellContext`ytzhs$$ = 0., $CellContext`yzs$$ = 
        0.}, "ControllerVariables" :> {
        Hold[$CellContext`tzhs$$, $CellContext`tzhs$259950$$, 0], 
        Hold[$CellContext`xzs$$, $CellContext`xzs$259951$$, 0], 
        Hold[$CellContext`yzs$$, $CellContext`yzs$259952$$, 0], 
        Hold[$CellContext`szangle$$, $CellContext`szangle$259953$$, 0], 
        Hold[$CellContext`absorp$$, $CellContext`absorp$259954$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[
                 0.8], $CellContext`staticpolygons11168982014115105024113498$$\
, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons12168982014115105024114986$$, 
                  Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`szangle$$], -
                    Sin[Degree $CellContext`szangle$$]}, {
                    Sin[Degree $CellContext`szangle$$], 
                    Cos[Degree $CellContext`szangle$$]}}, {
                    16., 0}}]], \
$CellContext`staticpolygons13168982014115105024116296$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction1168982014115105024119989[$\
CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$], And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]],
                     TrackedSymbols :> {$CellContext`tzhs$$, \
$CellContext`xzs$$, $CellContext`yzs$$, $CellContext`szangle$$}], 
                   SynchronousUpdating -> False]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[If[
                    
                    Or[$CellContext`laststartpostzhs$$ != \
{$CellContext`xzs$$, $CellContext`yzs$$}, $CellContext`lasttzhs$$ =!= \
$CellContext`tzhs$$], $CellContext`laststartpostzhs$$ = {$CellContext`xzs$$, \
$CellContext`yzs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`laststartpostzhs$$, \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$}}, \
({$CellContext`laststartpostzhs$$, {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xtzhs$$, $CellContext`ytzhs$$} != \
$CellContext`lastlocpostzhs$$, $CellContext`lasttzhs$$ != \
$CellContext`tzhs$$], $CellContext`lastlocpostzhs$$ = {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$}), \
({$CellContext`xtzhs$$, $CellContext`ytzhs$$} = #; $CellContext`xofftzhs$$ = \
$CellContext`xtzhs$$ - $CellContext`xzs$$; $CellContext`yofftzhs$$ = \
$CellContext`ytzhs$$ - $CellContext`yzs$$; $CellContext`radiustzhs$$ = 
                    Sqrt[$CellContext`xofftzhs$$^2 + \
$CellContext`yofftzhs$$^2]; $CellContext`tzhs$$ = 
                    Chop[ArcTan[$CellContext`xofftzhs$$, \
$CellContext`yofftzhs$$]/
                    Degree]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["tzhs = ", 
                    ToString[$CellContext`tzhs$$]]]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[
                  If[$CellContext`lastszangle$$ =!= $CellContext`szangle$$, \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`laststartposszangle$$, \
{$CellContext`xszangle$$, $CellContext`yszangle$$}}, \
({$CellContext`laststartposszangle$$, {$CellContext`xszangle$$, \
$CellContext`yszangle$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xszangle$$, $CellContext`yszangle$$} != \
$CellContext`lastlocposszangle$$, $CellContext`lastszangle$$ != \
$CellContext`szangle$$], $CellContext`lastlocposszangle$$ = \
{$CellContext`xszangle$$, $CellContext`yszangle$$}; \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$}), ({$CellContext`xszangle$$, \
$CellContext`yszangle$$} = #; $CellContext`xoffszangle$$ = \
$CellContext`xszangle$$ - 
                    16.; $CellContext`yoffszangle$$ = $CellContext`yszangle$$ + 
                    0; $CellContext`radiusszangle$$ = 
                    Sqrt[$CellContext`xoffszangle$$^2 + \
$CellContext`yoffszangle$$^2]; $CellContext`szangle$$ = 
                    Chop[ArcTan[$CellContext`xoffszangle$$, \
$CellContext`yoffszangle$$]/
                    Degree]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["szangle = ", 
                    ToString[$CellContext`szangle$$]]]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xzs$$, $CellContext`yzs$$}, \
({$CellContext`xzs$$, $CellContext`yzs$$} = Chop[#])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["{xzs, yzs} = ", 
                    ToString[
                    Chop[{$CellContext`xzs$$, $CellContext`yzs$$}]]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "Absorption" -> Dynamic[
             ListDensityPlot[
              
              Apply[$CellContext`rayfunction2168982014115105030986193, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$, $CellContext`absorp$$}], {
              PlotLabel -> "Absorption", PlotRange -> {0, All}, AspectRatio -> 
               0.6, DataRange -> {{0, 9}, {(-9)/2, 9/2}}, Frame -> True, Axes -> 
               True, Mesh -> False, ImageSize -> 600, 
               ColorFunction -> (Hue[0.65 - # 0.65, 1, # 0.9 + 0.1]& )}], 
             SynchronousUpdating -> True], "No Mirror" -> Dynamic[
             ListDensityPlot[
              
              Apply[$CellContext`rayfunction3168982014115105034984956, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`absorp$$}], {
              PlotLabel -> "No Mirror", PlotRange -> {0, All}, AspectRatio -> 
               0.6, DataRange -> {{0, 9}, {(-9)/2, 9/2}}, Frame -> True, Axes -> 
               True, Mesh -> False, ImageSize -> 600, 
               ColorFunction -> (Hue[0.65 - # 0.65, 1, # 0.9 + 0.1]& )}], 
             SynchronousUpdating -> True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`tzhs$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`xzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`yzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`szangle$$, 5.}, -175., 185., 
         ControlType -> None}, {{$CellContext`absorp$$, 0.1}, 0.001, 0.2, 
         ControlType -> None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Style[
         Grid[{{"absorp", 
            InputField[
             Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable1593168982014115105034996411; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
              Dynamic[$CellContext`minabsorp$$], 
              Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable1593168982014115105034996411; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]], {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "tzhs", "xzs", "yzs", "szangle", 
                   "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xtzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`ytzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiustzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xofftzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`yofftzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpostzhs$$, {0., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocpostzhs$$, {0.5, 0.}}, ControlType -> 
         None}, {{$CellContext`lasttzhs$$, 0}, ControlType -> 
         None}, {{$CellContext`xszangle$$, 16.498097349045874`}, ControlType -> 
         None}, {{$CellContext`yszangle$$, 0.04357787137382908}, ControlType -> 
         None}, {{$CellContext`radiusszangle$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xoffszangle$$, 0.4980973490458728}, 
         ControlType -> 
         None}, {{$CellContext`yoffszangle$$, 0.04357787137382908}, 
         ControlType -> 
         None}, {{$CellContext`laststartposszangle$$, {16., 0}}, ControlType -> 
         None}, {{$CellContext`lastlocposszangle$$, {16.498097349045874`, 
          0.04357787137382908}}, ControlType -> 
         None}, {{$CellContext`lastszangle$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons11168982014115105024113498$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons12168982014115105024114986$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons13168982014115105024116296$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5}, SynchronousInitialization -> 
        False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {495., 500.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction1168982014115105024119989 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukgHN/HY
kouu2+H6nigFd0kx4jKHkPkQEDCV3xGZRuhTc8BuDun+MgaDzxjhhl18qIYb
gwOEgoUbjE+8u9FFzoDBG4xwwy4+VMONwwFCw8INxife3egiRuB09Rgj3LCL
D9VwE3CA0LBwg/GJdze6iAE4fC5jhBt28aEabiIOEBoWbjA+8e7GLr7Bhjjx
oRpuEg4QGhZuMD7x7kYXsYCkKyLFh2q4yThAaFi4wfjEuxtdBBI+j4kUH6rh
puAAoWHhBuMT7250kQuQepNI8aEabkoOEBoWbjA+8e5GFzGBtNOIFB+q4abi
AKFh4QbjE+9udBEmMPmDSPGhGm6w8EKniXc3jAUADhwmaw==
                
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$383}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$383 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$383), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$383, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$383}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258759.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$384}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$384 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$384), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$384, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$384}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258787.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$387}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$387 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$387), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$387, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$387}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258871.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$388}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$388 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$388), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$388, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$388}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258899.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$386}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$386 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$386), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$386, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$386}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258843.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$385}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$385 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$385), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$385, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$385}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258815.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$389}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$389 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$389), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$389, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$389}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 258951.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    258759.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    258787.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    258871.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    258899.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    258843.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    258815.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    258951.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$390}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$390 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$390), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$390, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$390}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259105.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$392}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$392 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$392), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$392, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$392}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259106.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$390}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$390 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$390), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$390, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$390}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259107.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$392}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$392 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$392), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$392, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$392}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259108.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$391}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$391 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$391), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$391, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$391}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259109.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$391}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$391 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$391), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$391, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$391}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259110.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    259105.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    259106.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    259107.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    259108.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    259109.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    259110.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; 
                    $CellContext`rxhlp$ = $CellContext`rx$ + \
$CellContext`ray1$ $CellContext`xunit$; $CellContext`ryhlp$ = \
$CellContext`ry$ + $CellContext`ray1$ $CellContext`yunit$; \
$CellContext`rzhlp$ = $CellContext`rz$ + $CellContext`ray1$ \
$CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction2168982014115105030986193 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwzEJACAABMAXewhWMoLgbP9NB1t4B9fnHqsmKXd7AQAAAAAAgH8c+ScB
6g==
             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3Gd0U4fS+GvRTRfddNFNC6Kbvummi27AAVECxjQBBgwxsDEETBfddNFN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                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$359}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$359 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$359), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$359, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$359}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234016.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$360}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$360 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$360), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$360, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$360}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234044.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$363}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$363 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$363), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$363, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$363}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234128.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$364}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$364 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$364), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$364, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$364}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234156.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$362}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$362 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$362), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$362, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$362}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234100.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$361}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$361 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$361), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$361, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$361}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234072.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$393}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$393 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$393), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$393, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$393}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259144.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    234016.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    234044.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    234128.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    234156.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    
                    234100.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    234072.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    259144.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$394}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$394 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$394), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$394, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$394}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259298.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$396}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 10., Part[#, 2] >= -10., 
                    Part[#, 3] >= -10., Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$396 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$396), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$396, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$396}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259299.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$394}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$394 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$394), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$394, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$394}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259300.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$396}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$396 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$396), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$396, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$396}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259301.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$395}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$395 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$395), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$395, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$395}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259302.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$395}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$395 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$395), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$395, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$395}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259303.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    259298.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    259299.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    259300.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    259301.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 
                    1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    259302.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    259303.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Part[$CellContext`griddata$, 
             1]], $CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction3168982014115105034984956 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwzEJACAABMAXewhWMoLgbP9NB1t4B9fnHqsmKXd7AQAAAAAAgH8c+ScB
6g==
             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3Hd0zAv3+PtBECWMHn306KNH/+hBMHoQDIKco40e/SNaiDIcJfpwlOiD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                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$359}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$359 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$359), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$359, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$359}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234016.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$360}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$360 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$360), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$360, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$360}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234044.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$363}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$363 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$363), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$363, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$363}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234128.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$364}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$364 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$364), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$364, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$364}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234156.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$362}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$362 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$362), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$362, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$362}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234100.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$361}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$361 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$361), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$361, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$361}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 234072.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    234016.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    234044.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    234128.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    234156.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] Part[$CellContext`XAxis$, 3],
                     -(Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    234100.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    234072.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    234210, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234016, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234044, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234128, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234156, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    234100, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = Take[
                    Join[
                    N[
                    Dimensions[$CellContext`griddata$]], {1., 1.}], 
                    3]; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, #3, #2, #] = 
                    Part[$CellContext`griddata$, #3, #2, #] + \
$CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$397}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$397 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$397), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$397, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$397}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259406.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$399}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$399 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$399), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$399, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$399}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259407.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$397}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$397 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$397), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$397, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$397}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259408.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$399}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$399 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$399), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$399, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$399}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259409.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$398}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$398 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$398), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$398, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$398}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259410.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$398}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$398 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$398), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$398, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$398}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 259411.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    259406.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    259407.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    259408.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    259409.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    259410.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    259411.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Part[$CellContext`griddata$, 
             1]], $CellContext`compileoptionsetting$]]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598787810424695*^9, 3.598787820462755*^9}, 
   3.598787972761451*^9, {3.5987894272844887`*^9, 3.5987894347839193`*^9}, {
   3.598789484815424*^9, 3.5987894970360813`*^9}, {3.598790366562512*^9, 
   3.598790381655753*^9}, {3.598790416978981*^9, 3.598790429528521*^9}, {
   3.598793438499086*^9, 3.598793474448318*^9}, {3.598794011674712*^9, 
   3.5987940154839907`*^9}, {3.598794119928692*^9, 3.598794130138414*^9}, {
   3.5987942059029827`*^9, 3.598794209578868*^9}, {3.5988810829038553`*^9, 
   3.5988810853539867`*^9}, {3.614739160034458*^9, 3.614739165358305*^9}, {
   3.614739198414187*^9, 3.614739201602573*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Modified Example with ListPlot3D into one-dimensional data\
\>", "Section",
 CellChangeTimes->{{3.598877088109701*^9, 3.598877116902734*^9}, {
  3.598877167896738*^9, 3.5988771739512253`*^9}, {3.598878249304823*^9, 
  3.598878256766881*^9}}],

Cell[CellGroupData[{

Cell["\<\
Dimensions[{Table[0.,{30},{30}]}]\
\>", "Input",
 CellChangeTimes->{{3.598877310604426*^9, 3.5988773237174263`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "30", ",", "30"}], "}"}]], "Output",
 CellChangeTimes->{3.598877324130109*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Length[Apply[Join,Table[0.,{30*30}]]]\
\>", "Input",
 CellChangeTimes->{{3.598878010922196*^9, 3.598878019921069*^9}}],

Cell[BoxData["900"], "Output",
 CellChangeTimes->{3.598878020344289*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gainslab = CustomGrid[SlabPrism[10], griddata, 9, \
SymbolicValues->{griddata->Table[0.,{30*30}],absorp->0.1},
\tGridFunction->Function[griddata[[(#2-1)*30+#1]]=griddata[[(#2-1)*30+#1]]+\
Intensity*Exp[#4*absorp];Intensity = Intensity*Exp[-#4*absorp]], 
\t\tEmbedGridData->True, GridOrder->3, GridDimensions->{1,30,30}, \
ReportedFunction->Hold[Partition[Partition[griddata,30],30]]]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.598018682495386*^9, 
   3.598018685071406*^9}, {3.5983586945572042`*^9, 3.5983587019643383`*^9}, {
   3.5986167063493357`*^9, 3.598616708300345*^9}, {3.598616749468322*^9, 
   3.598616781307159*^9}, {3.598616822165442*^9, 3.598616905136224*^9}, {
   3.59861694510306*^9, 3.5986170016457233`*^9}, {3.598617139222601*^9, 
   3.598617172014608*^9}, {3.598617685355007*^9, 3.598617707574271*^9}, {
   3.598617770991014*^9, 3.598617773188614*^9}, {3.5986178250202436`*^9, 
   3.598617990576351*^9}, {3.598618023555862*^9, 3.5986180278039827`*^9}, {
   3.598618096492874*^9, 3.598618104916382*^9}, {3.598618152205185*^9, 
   3.598618265855753*^9}, {3.598618297071982*^9, 3.5986183010146933`*^9}, {
   3.598618331216523*^9, 3.598618331831071*^9}, {3.5986183899972353`*^9, 
   3.598618421563044*^9}, {3.5986185009868507`*^9, 3.5986185068896914`*^9}, {
   3.598618653682613*^9, 3.59861868614471*^9}, {3.598618738921391*^9, 
   3.598618743985243*^9}, 3.5986188285199137`*^9, {3.598618866776342*^9, 
   3.598618867838866*^9}, {3.5986190004339447`*^9, 3.598619028792245*^9}, {
   3.598619362025923*^9, 3.598619365008605*^9}, {3.5986197342580957`*^9, 
   3.598619747121016*^9}, {3.598619955573572*^9, 3.598619962068234*^9}, 
   3.598620032682416*^9, {3.598620156507202*^9, 3.598620164738914*^9}, 
   3.598621062515483*^9, {3.598712813840581*^9, 3.5987128184058523`*^9}, 
   3.598713443321837*^9, {3.598723011077673*^9, 3.598723035051834*^9}, {
   3.5987231973758802`*^9, 3.598723221719447*^9}, {3.5987233556133137`*^9, 
   3.5987233737716017`*^9}, {3.598723669213241*^9, 3.598723676413336*^9}, 
   3.598724248577115*^9, {3.598783578389386*^9, 3.5987835915787992`*^9}, 
   3.598785013378652*^9, {3.5987852234833927`*^9, 3.5987852260575533`*^9}, {
   3.598785463616057*^9, 3.598785495357689*^9}, {3.5987874460655518`*^9, 
   3.598787446568397*^9}, {3.598787518012682*^9, 3.598787518459611*^9}, {
   3.598789641944824*^9, 3.598789646592228*^9}, {3.598790214801388*^9, 
   3.5987902163291597`*^9}, {3.598793356375049*^9, 3.598793367167121*^9}, {
   3.5988771876553164`*^9, 3.598877291486206*^9}, {3.5988773385760393`*^9, 
   3.598877347927306*^9}, {3.598877622810707*^9, 3.598877625841036*^9}, {
   3.59887803227381*^9, 3.598878039716282*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"SlabPrism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "5"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", "griddata", 
      ",", "9", ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"absorp", "\[Rule]", "0.1`"}], "}"}]}], ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"griddata", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"#2", "-", "1"}], ")"}], " ", "30"}], "+", "#1"}], 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{"griddata", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#2", "-", "1"}], ")"}], " ", "30"}], "+", "#1"}], 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"Intensity", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"#4", " ", "absorp"}], "]"}]}]}]}], ";", 
           RowBox[{"Intensity", "=", 
            RowBox[{"Intensity", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", "#4"}], " ", "absorp"}], "]"}]}]}]}], ")"}], 
         "&"}], ")"}]}], ",", 
      RowBox[{"EmbedGridData", "\[Rule]", "True"}], ",", 
      RowBox[{"GridOrder", "\[Rule]", "3"}], ",", 
      RowBox[{"GridDimensions", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "30", ",", "30"}], "}"}]}], ",", 
      RowBox[{"ReportedFunction", "\[Rule]", 
       RowBox[{"Hold", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{"griddata", ",", "30"}], "]"}], ",", "30"}], "]"}], 
        "]"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.598785481720141*^9, 3.598787447680771*^9, 3.598787519332398*^9, 
   3.598787787438519*^9, 3.5987893991684237`*^9, {3.598789638608594*^9, 
   3.5987896476037273`*^9}, 3.598789730546843*^9, 3.5987902174790277`*^9, 
   3.598793372623831*^9, 3.5988773617939377`*^9, 3.598877631677249*^9, 
   3.598878083108705*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[LineOfRays[3,NumberOfRays->11],{{xzs,0},{yzs,0.}},{\
tzhs,0}],Resonate[{Move[SlabPrism[10],5],Move[Mirror[{10,10}],16,{szangle,5}]}\
],Boundary[20]},
\t{DynamicFrame[PlotType->TopView],
\tDynamicFrame[PlotType->ListPlot3D,PlotLabel->\"Absorption\",PlotRange->{0,\
All},AspectRatio->1,
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Resonate[{Move[gainslab,5],Move[\
Mirror[{10,10}],16,{szangle,5}]}],Boundary[20]}]}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.59861907189555*^9, 3.59861907603083*^9}, {
   3.5986192376173153`*^9, 3.598619243843154*^9}, {3.598619323601527*^9, 
   3.598619326269944*^9}, {3.5986195567035427`*^9, 3.598619644024191*^9}, {
   3.598619848748253*^9, 3.5986198511948767`*^9}, {3.5986200267348623`*^9, 
   3.598620132315246*^9}, {3.598620263843527*^9, 3.598620286210291*^9}, {
   3.5986205657846117`*^9, 3.598620683654751*^9}, {3.598620715446212*^9, 
   3.598620768892735*^9}, 3.598620803614503*^9, 3.5986208399808807`*^9, {
   3.598709580833399*^9, 3.598709610655719*^9}, {3.598713614035285*^9, 
   3.598713641162293*^9}, {3.5987228963934937`*^9, 3.5987229059525223`*^9}, {
   3.598722963206867*^9, 3.59872297836563*^9}, {3.598723162145793*^9, 
   3.59872318311202*^9}, {3.598724182448244*^9, 3.598724206824198*^9}, {
   3.5987834755754137`*^9, 3.5987835172368917`*^9}, 3.598783553775072*^9, {
   3.598783648841077*^9, 3.598783729877985*^9}, {3.59878378137654*^9, 
   3.5987838738456306`*^9}, {3.598783914606614*^9, 3.598783927916171*^9}, {
   3.598783992597123*^9, 3.598784058120701*^9}, {3.598784090552135*^9, 
   3.598784098287863*^9}, 3.598784350306773*^9, {3.59878464861152*^9, 
   3.598784690963435*^9}, {3.598784967972073*^9, 3.598784971546756*^9}, {
   3.598785061601509*^9, 3.5987850667629747`*^9}, {3.598789962290284*^9, 
   3.598790000126421*^9}, {3.598790208027376*^9, 3.598790210265657*^9}, {
   3.5988774050682907`*^9, 3.5988774247866793`*^9}, 3.598877644632618*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`absorp$$ = 
    0.1, $CellContext`lastlocposszangle$$ = {
    16.96824884049352, -0.3259432748506174}, $CellContext`lastlocpostzhs$$ = {
    0.5, 0.}, $CellContext`laststartposszangle$$ = {
    16., 0}, $CellContext`laststartpostzhs$$ = {0., 
    0.}, $CellContext`lastszangle$$ = -18.604865582321487`, \
$CellContext`lasttzhs$$ = 0., $CellContext`maxabsorp$$ = 
    0.2, $CellContext`maxszangle$$ = 185., $CellContext`maxtzhs$$ = 
    180., $CellContext`maxxzs$$ = 10, $CellContext`maxyzs$$ = 
    10, $CellContext`minabsorp$$ = 
    0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = -180., \
$CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 
    1.0216383095486334`, $CellContext`radiustzhs$$ = 
    0.5, $CellContext`staticpolygons11174012014116102131418430$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
      
      "]]}, $CellContext`staticpolygons12174012014116102131419488$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons13174012014116102131420528$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
      
      "]]}, $CellContext`szangle$$ = -18.604865582321487`, \
$CellContext`tzhs$$ = 0., $CellContext`xoffszangle$$ = 
    0.9682488404935192, $CellContext`xofftzhs$$ = 
    0.5, $CellContext`xszangle$$ = 16.96824884049352, $CellContext`xtzhs$$ = 
    0.5, $CellContext`xzs$$ = 
    0., $CellContext`yoffszangle$$ = -0.32594327485061747`, \
$CellContext`yofftzhs$$ = 
    0., $CellContext`yszangle$$ = -0.32594327485061747`, $CellContext`ytzhs$$ \
= 0., $CellContext`yzs$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`tzhs$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`xzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`szangle$$], 5.}, -175., 185.}, {{
       Hold[$CellContext`absorp$$], 0.1}, 0.001, 0.2}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Style[
        Grid[{{"absorp", 
           InputField[
            Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable1593174012014116102137556523; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
             Dynamic[$CellContext`minabsorp$$], 
             Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable1593174012014116102137556523; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "tzhs", "xzs", "yzs", "szangle", 
               "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xtzhs$$], 0.5}}, {{
       Hold[$CellContext`ytzhs$$], 0.}}, {{
       Hold[$CellContext`radiustzhs$$], 0.5}}, {{
       Hold[$CellContext`xofftzhs$$], 0.5}}, {{
       Hold[$CellContext`yofftzhs$$], 0.}}, {{
       Hold[$CellContext`laststartpostzhs$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpostzhs$$], {0.5, 0.}}}, {{
       Hold[$CellContext`lasttzhs$$], 0}}, {{
       Hold[$CellContext`xszangle$$], 16.498097349045874`}}, {{
       Hold[$CellContext`yszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`radiusszangle$$], 0.5}}, {{
       Hold[$CellContext`xoffszangle$$], 0.4980973490458728}}, {{
       Hold[$CellContext`yoffszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`laststartposszangle$$], {16., 0}}}, {{
       Hold[$CellContext`lastlocposszangle$$], {16.498097349045874`, 
       0.04357787137382908}}}, {{
       Hold[$CellContext`lastszangle$$], 0}}, {{
       Hold[$CellContext`staticpolygons11174012014116102131418430$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons12174012014116102131419488$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons13174012014116102131420528$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
         "]]}}}}, Typeset`size$$ = {
    816., {433.625, 439.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`tzhs$9856$$ = 
    0, $CellContext`xzs$9861$$ = 0, $CellContext`yzs$9862$$ = 
    0, $CellContext`szangle$9863$$ = 0, $CellContext`absorp$9864$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`absorp$$ = 
        0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
         0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {0.5, 
         0.}, $CellContext`laststartposszangle$$ = {
         16., 0}, $CellContext`laststartpostzhs$$ = {0., 
         0.}, $CellContext`lastszangle$$ = 0, $CellContext`lasttzhs$$ = 
        0, $CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
        185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
        10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
        0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = \
-180., $CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
        0.5, $CellContext`staticpolygons11174012014116102131418430$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
           
           "]]}, $CellContext`staticpolygons12174012014116102131419488$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons13174012014116102131420528$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
           
           "]]}, $CellContext`szangle$$ = 5., $CellContext`tzhs$$ = 
        0., $CellContext`xoffszangle$$ = 
        0.4980973490458728, $CellContext`xofftzhs$$ = 
        0.5, $CellContext`xszangle$$ = 
        16.498097349045874`, $CellContext`xtzhs$$ = 0.5, $CellContext`xzs$$ = 
        0., $CellContext`yoffszangle$$ = 
        0.04357787137382908, $CellContext`yofftzhs$$ = 
        0., $CellContext`yszangle$$ = 
        0.04357787137382908, $CellContext`ytzhs$$ = 0., $CellContext`yzs$$ = 
        0.}, "ControllerVariables" :> {
        Hold[$CellContext`tzhs$$, $CellContext`tzhs$9856$$, 0], 
        Hold[$CellContext`xzs$$, $CellContext`xzs$9861$$, 0], 
        Hold[$CellContext`yzs$$, $CellContext`yzs$9862$$, 0], 
        Hold[$CellContext`szangle$$, $CellContext`szangle$9863$$, 0], 
        Hold[$CellContext`absorp$$, $CellContext`absorp$9864$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[
                 0.8], $CellContext`staticpolygons11174012014116102131418430$$\
, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons12174012014116102131419488$$, 
                  Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`szangle$$], -
                    Sin[Degree $CellContext`szangle$$]}, {
                    Sin[Degree $CellContext`szangle$$], 
                    Cos[Degree $CellContext`szangle$$]}}, {
                    16., 0}}]], \
$CellContext`staticpolygons13174012014116102131420528$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction1174012014116102131423378[$\
CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$], And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]],
                     TrackedSymbols :> {$CellContext`tzhs$$, \
$CellContext`xzs$$, $CellContext`yzs$$, $CellContext`szangle$$}], 
                   SynchronousUpdating -> False]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[If[
                    
                    Or[$CellContext`laststartpostzhs$$ != \
{$CellContext`xzs$$, $CellContext`yzs$$}, $CellContext`lasttzhs$$ =!= \
$CellContext`tzhs$$], $CellContext`laststartpostzhs$$ = {$CellContext`xzs$$, \
$CellContext`yzs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`laststartpostzhs$$, \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$}}, \
({$CellContext`laststartpostzhs$$, {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xtzhs$$, $CellContext`ytzhs$$} != \
$CellContext`lastlocpostzhs$$, $CellContext`lasttzhs$$ != \
$CellContext`tzhs$$], $CellContext`lastlocpostzhs$$ = {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$}), \
({$CellContext`xtzhs$$, $CellContext`ytzhs$$} = #; $CellContext`xofftzhs$$ = \
$CellContext`xtzhs$$ - $CellContext`xzs$$; $CellContext`yofftzhs$$ = \
$CellContext`ytzhs$$ - $CellContext`yzs$$; $CellContext`radiustzhs$$ = 
                    Sqrt[$CellContext`xofftzhs$$^2 + \
$CellContext`yofftzhs$$^2]; $CellContext`tzhs$$ = 
                    Chop[ArcTan[$CellContext`xofftzhs$$, \
$CellContext`yofftzhs$$]/
                    Degree]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["tzhs = ", 
                    ToString[$CellContext`tzhs$$]]]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[
                  If[$CellContext`lastszangle$$ =!= $CellContext`szangle$$, \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`laststartposszangle$$, \
{$CellContext`xszangle$$, $CellContext`yszangle$$}}, \
({$CellContext`laststartposszangle$$, {$CellContext`xszangle$$, \
$CellContext`yszangle$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xszangle$$, $CellContext`yszangle$$} != \
$CellContext`lastlocposszangle$$, $CellContext`lastszangle$$ != \
$CellContext`szangle$$], $CellContext`lastlocposszangle$$ = \
{$CellContext`xszangle$$, $CellContext`yszangle$$}; \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$}), ({$CellContext`xszangle$$, \
$CellContext`yszangle$$} = #; $CellContext`xoffszangle$$ = \
$CellContext`xszangle$$ - 
                    16.; $CellContext`yoffszangle$$ = $CellContext`yszangle$$ + 
                    0; $CellContext`radiusszangle$$ = 
                    Sqrt[$CellContext`xoffszangle$$^2 + \
$CellContext`yoffszangle$$^2]; $CellContext`szangle$$ = 
                    Chop[ArcTan[$CellContext`xoffszangle$$, \
$CellContext`yoffszangle$$]/
                    Degree]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["szangle = ", 
                    ToString[$CellContext`szangle$$]]]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xzs$$, $CellContext`yzs$$}, \
({$CellContext`xzs$$, $CellContext`yzs$$} = Chop[#])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["{xzs, yzs} = ", 
                    ToString[
                    Chop[{$CellContext`xzs$$, $CellContext`yzs$$}]]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "Absorption" -> Dynamic[
             ListPlot3D[
              
              Apply[$CellContext`rayfunction2174012014116102137548650, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$, $CellContext`absorp$$}], {
              PlotLabel -> "Absorption", PlotRange -> {0, All}, AspectRatio -> 
               1, DataRange -> {{0, 9}, {(-9)/2, 9/2}, {(-9)/2, 9/2}}, Axes -> 
               True, Mesh -> False, ImageSize -> 600}], SynchronousUpdating -> 
             True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`tzhs$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`xzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`yzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`szangle$$, 5.}, -175., 185., 
         ControlType -> None}, {{$CellContext`absorp$$, 0.1}, 0.001, 0.2, 
         ControlType -> None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Style[
         Grid[{{"absorp", 
            InputField[
             Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable1593174012014116102137556523; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
              Dynamic[$CellContext`minabsorp$$], 
              Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable1593174012014116102137556523; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]], {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "tzhs", "xzs", "yzs", "szangle", 
                   "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xtzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`ytzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiustzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xofftzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`yofftzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpostzhs$$, {0., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocpostzhs$$, {0.5, 0.}}, ControlType -> 
         None}, {{$CellContext`lasttzhs$$, 0}, ControlType -> 
         None}, {{$CellContext`xszangle$$, 16.498097349045874`}, ControlType -> 
         None}, {{$CellContext`yszangle$$, 0.04357787137382908}, ControlType -> 
         None}, {{$CellContext`radiusszangle$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xoffszangle$$, 0.4980973490458728}, 
         ControlType -> 
         None}, {{$CellContext`yoffszangle$$, 0.04357787137382908}, 
         ControlType -> 
         None}, {{$CellContext`laststartposszangle$$, {16., 0}}, ControlType -> 
         None}, {{$CellContext`lastlocposszangle$$, {16.498097349045874`, 
          0.04357787137382908}}, ControlType -> 
         None}, {{$CellContext`lastszangle$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons11174012014116102131418430$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons12174012014116102131419488$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons13174012014116102131420528$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5}, SynchronousInitialization -> 
        False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {495., 500.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction1174012014116102131423378 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + 
                   $CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ \
$CellContext`symr2$ + $CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ \
$CellContext`symr8$, $CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ \
$CellContext`symr6$ + $CellContext`r3$ $CellContext`symr9$}; \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$} = \
{$CellContext`r4$ $CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + \
$CellContext`r6$ $CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + \
$CellContext`r5$ $CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, \
$CellContext`r4$ $CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + \
$CellContext`r6$ $CellContext`symr9$}; {$CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$} = {$CellContext`r7$ \
$CellContext`symr1$ + $CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ \
$CellContext`symr7$, $CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ \
$CellContext`symr5$ + $CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ \
$CellContext`symr3$ + $CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ \
$CellContext`symr9$}; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
{{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}, \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$}, \
{$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$}}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukgHN/HY
kouu2+H6nigFd0kx4jKHkPkQ0KBz0AGZRuhTQ+MT7250EWMw+IwRbtjFh2q4
MUBpNTQ+8e5GFzkDBm8wwg27+FANNw4orYbGJ97d6CJG4HT1GCPcsIsP1XAT
gNJqaHzi3Y0uYgAOn8sY4YZdfKiGmwiUVkPjE+9u7OIbbIgTH6rhJgGl1dD4
xLsbXcQCkq6IFB+q4SYDpdXQ+MS7G10EEj6PiRQfquGmAKXV0PjEuxtd5AKk
3iRSfKiGmxKUVkPjE+9udBETSDuNSPGhGm4qUFoNjU+8u9FFmMDkDyLFh2q4
qeGgiXc3jAUAX6owuw==
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$53}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$53 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$53), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$53, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$53}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8822.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$54}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$54 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$54), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$54, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$54}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8850.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$65}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$65 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$65), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$65, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$65}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8934.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$69}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$69 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$69), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$69, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$69}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8962.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$59}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$59 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$59), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$59, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$59}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8906.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$55}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$55 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$55), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$55, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$55}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8878.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$70}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$70 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$70), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$70, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$70}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9014.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    8822.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {5., 0, 0}; 
                    $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    8850.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = \
False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    8934.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    8962.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    8906.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 
                    1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    8878.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    9014.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$72}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$72 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$72), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$72, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$72}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9168.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$75}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$75 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$75), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$75, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$75}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9169.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$72}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$72 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$72), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$72, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$72}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9170.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$75}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$75 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$75), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$75, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$75}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9171.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$74}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$74 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$74), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$74, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$74}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9172.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$74}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$74 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$74), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$74, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$74}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9173.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    9168.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    9169.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    9170.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    9171.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    9172.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    9173.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[
            Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction2174012014116102137548650 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwUENACAMBLAjKJklJJDwxgTCJ4S2te86I8mbAQAAAAAAAD7S1cwCMg==

             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3HdUk4n26P3YsceOjqNRUbFHx4I9dlTU2FEsUVGxx479Ecvg2IIVldHY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                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$37}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$37 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$37), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$37, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$37}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4508.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$38}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$38 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$38), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$38, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$38}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4536.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$49}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$49 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$49), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$49, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$49}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4620.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$52}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$52 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$52), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$52, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$52}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4648.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$43}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$43 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$43), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$43, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$43}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4592.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$41}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$41 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$41), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$41, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$41}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 4564.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$76}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$76 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$76), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$76, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$76}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9207.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    4508.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4702, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4508, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4536, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4620, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4648, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4592, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    4536.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4702, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4508, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4536, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4620, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4648, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4592, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    4620.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4702, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4508, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4536, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4620, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4648, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4592, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    4648.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4702, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4508, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4536, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4620, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4648, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4592, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    4592.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4702, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4508, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4536, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4620, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4648, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4592, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    4564.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    4702, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4508, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4536, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4620, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4648, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    4592, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    9207.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$79}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$79 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$79), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$79, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$79}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9361.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$81}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$81 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$81), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$81, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$81}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9362.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$79}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$79 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$79), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$79, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$79}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9363.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$81}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$81 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$81), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$81, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$81}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9364.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$80), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$80, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9365.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$80), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$80, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 9366.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    9361.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 
                    1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    9362.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    9363.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    9364.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    9365.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    9366.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Partition[
             Partition[$CellContext`griddata$, 30], 
             30]], $CellContext`compileoptionsetting$]]); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.5988780994356527`*^9, {3.598878132926753*^9, 3.59887814790224*^9}, {
   3.5988782263587427`*^9, 3.598878239394261*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Modified Example with ListPlot3D into one-dimensional data using \
CustomDisplayFunction\
\>", "Section",
 CellChangeTimes->{{3.598877088109701*^9, 3.598877116902734*^9}, {
  3.598877167896738*^9, 3.5988771739512253`*^9}, {3.598878249304823*^9, 
  3.598878256766881*^9}, {3.598878418321109*^9, 3.59887842671451*^9}}],

Cell[CellGroupData[{

Cell["\<\
Dimensions[{Table[0.,{30},{30}]}]\
\>", "Input",
 CellChangeTimes->{{3.598877310604426*^9, 3.5988773237174263`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "30", ",", "30"}], "}"}]], "Output",
 CellChangeTimes->{3.598877324130109*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Length[Apply[Join,Table[0.,{30*30}]]]\
\>", "Input",
 CellChangeTimes->{{3.598878010922196*^9, 3.598878019921069*^9}}],

Cell[BoxData["900"], "Output",
 CellChangeTimes->{3.598878020344289*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[CustomGrid]", "Input",
 CellChangeTimes->{{3.598878523619816*^9, 3.598878530779101*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TakeFrom", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"CreatedRay", ",", "OriginalRay", ",", "ChangedSurface"}], 
     "}"}]}], ",", 
   RowBox[{"ReplaceFor", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"OriginalRay", ",", "AllCreatedRays", ",", "CreatedRay"}], 
     "}"}]}], ",", 
   RowBox[{"GridCoordinateOffset", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.1`", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"SurfaceID", "\[Rule]", "False"}], ",", 
   RowBox[{"RunningCommentary", "\[Rule]", "False"}], ",", 
   RowBox[{"SymbolicValues", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"EmbedGridData", "\[Rule]", "False"}], ",", 
   RowBox[{"GridOrder", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"GridDimensions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
   RowBox[{"CustomDisplayFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}], ",", 
   RowBox[{"GridFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.598878531035434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gainslab = CustomGrid[SlabPrism[10], griddata, 9, \
SymbolicValues->{griddata->Table[0.,{30*30}],absorp->0.1},
\tGridFunction->Function[griddata[[(#2-1)*30+#1]]=griddata[[(#2-1)*30+#1]]+\
Intensity*Exp[#4*absorp];Intensity = Intensity*Exp[-#4*absorp]], 
\t\tEmbedGridData->True, GridOrder->3, GridDimensions->{1,30,30}, \
ReportedFunction->griddata,CustomDisplayFunction->Function[Partition[\
Partition[#,30],30]]]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.598018682495386*^9, 
   3.598018685071406*^9}, {3.5983586945572042`*^9, 3.5983587019643383`*^9}, {
   3.5986167063493357`*^9, 3.598616708300345*^9}, {3.598616749468322*^9, 
   3.598616781307159*^9}, {3.598616822165442*^9, 3.598616905136224*^9}, {
   3.59861694510306*^9, 3.5986170016457233`*^9}, {3.598617139222601*^9, 
   3.598617172014608*^9}, {3.598617685355007*^9, 3.598617707574271*^9}, {
   3.598617770991014*^9, 3.598617773188614*^9}, {3.5986178250202436`*^9, 
   3.598617990576351*^9}, {3.598618023555862*^9, 3.5986180278039827`*^9}, {
   3.598618096492874*^9, 3.598618104916382*^9}, {3.598618152205185*^9, 
   3.598618265855753*^9}, {3.598618297071982*^9, 3.5986183010146933`*^9}, {
   3.598618331216523*^9, 3.598618331831071*^9}, {3.5986183899972353`*^9, 
   3.598618421563044*^9}, {3.5986185009868507`*^9, 3.5986185068896914`*^9}, {
   3.598618653682613*^9, 3.59861868614471*^9}, {3.598618738921391*^9, 
   3.598618743985243*^9}, 3.5986188285199137`*^9, {3.598618866776342*^9, 
   3.598618867838866*^9}, {3.5986190004339447`*^9, 3.598619028792245*^9}, {
   3.598619362025923*^9, 3.598619365008605*^9}, {3.5986197342580957`*^9, 
   3.598619747121016*^9}, {3.598619955573572*^9, 3.598619962068234*^9}, 
   3.598620032682416*^9, {3.598620156507202*^9, 3.598620164738914*^9}, 
   3.598621062515483*^9, {3.598712813840581*^9, 3.5987128184058523`*^9}, 
   3.598713443321837*^9, {3.598723011077673*^9, 3.598723035051834*^9}, {
   3.5987231973758802`*^9, 3.598723221719447*^9}, {3.5987233556133137`*^9, 
   3.5987233737716017`*^9}, {3.598723669213241*^9, 3.598723676413336*^9}, 
   3.598724248577115*^9, {3.598783578389386*^9, 3.5987835915787992`*^9}, 
   3.598785013378652*^9, {3.5987852234833927`*^9, 3.5987852260575533`*^9}, {
   3.598785463616057*^9, 3.598785495357689*^9}, {3.5987874460655518`*^9, 
   3.598787446568397*^9}, {3.598787518012682*^9, 3.598787518459611*^9}, {
   3.598789641944824*^9, 3.598789646592228*^9}, {3.598790214801388*^9, 
   3.5987902163291597`*^9}, {3.598793356375049*^9, 3.598793367167121*^9}, {
   3.5988771876553164`*^9, 3.598877291486206*^9}, {3.5988773385760393`*^9, 
   3.598877347927306*^9}, {3.598877622810707*^9, 3.598877625841036*^9}, {
   3.59887803227381*^9, 3.598878039716282*^9}, {3.598878436720544*^9, 
   3.598878461521723*^9}, 3.598878535334834*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"SlabPrism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "5"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", "griddata", 
      ",", "9", ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"absorp", "\[Rule]", "0.1`"}], "}"}]}], ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"griddata", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"#2", "-", "1"}], ")"}], " ", "30"}], "+", "#1"}], 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{"griddata", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#2", "-", "1"}], ")"}], " ", "30"}], "+", "#1"}], 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"Intensity", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"#4", " ", "absorp"}], "]"}]}]}]}], ";", 
           RowBox[{"Intensity", "=", 
            RowBox[{"Intensity", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", "#4"}], " ", "absorp"}], "]"}]}]}]}], ")"}], 
         "&"}], ")"}]}], ",", 
      RowBox[{"EmbedGridData", "\[Rule]", "True"}], ",", 
      RowBox[{"GridOrder", "\[Rule]", "3"}], ",", 
      RowBox[{"GridDimensions", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "30", ",", "30"}], "}"}]}], ",", 
      RowBox[{"ReportedFunction", "\[Rule]", "griddata"}], ",", 
      RowBox[{"CustomDisplayFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{
           RowBox[{"Partition", "[", 
            RowBox[{"#1", ",", "30"}], "]"}], ",", "30"}], "]"}], "&"}], 
        ")"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.598785481720141*^9, 3.598787447680771*^9, 3.598787519332398*^9, 
   3.598787787438519*^9, 3.5987893991684237`*^9, {3.598789638608594*^9, 
   3.5987896476037273`*^9}, 3.598789730546843*^9, 3.5987902174790277`*^9, 
   3.598793372623831*^9, 3.5988773617939377`*^9, 3.598877631677249*^9, 
   3.598878083108705*^9, 3.5988784660504017`*^9, 3.598878638086878*^9, 
   3.598878673603629*^9, 3.598878840251976*^9, 3.598878961004806*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[LineOfRays[3,NumberOfRays->11],{{xzs,0},{yzs,0.}},{\
tzhs,0}],Resonate[{Move[SlabPrism[10],5],Move[Mirror[{10,10}],16,{szangle,5}]}\
],Boundary[20]},
\t{DynamicFrame[PlotType->TopView],
\tDynamicFrame[PlotType->ListPlot3D,PlotLabel->\"Absorption\",PlotRange->{0,\
All},AspectRatio->1,
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Resonate[{Move[gainslab,5],Move[\
Mirror[{10,10}],16,{szangle,5}]}],Boundary[20]}]}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.59861907189555*^9, 3.59861907603083*^9}, {
   3.5986192376173153`*^9, 3.598619243843154*^9}, {3.598619323601527*^9, 
   3.598619326269944*^9}, {3.5986195567035427`*^9, 3.598619644024191*^9}, {
   3.598619848748253*^9, 3.5986198511948767`*^9}, {3.5986200267348623`*^9, 
   3.598620132315246*^9}, {3.598620263843527*^9, 3.598620286210291*^9}, {
   3.5986205657846117`*^9, 3.598620683654751*^9}, {3.598620715446212*^9, 
   3.598620768892735*^9}, 3.598620803614503*^9, 3.5986208399808807`*^9, {
   3.598709580833399*^9, 3.598709610655719*^9}, {3.598713614035285*^9, 
   3.598713641162293*^9}, {3.5987228963934937`*^9, 3.5987229059525223`*^9}, {
   3.598722963206867*^9, 3.59872297836563*^9}, {3.598723162145793*^9, 
   3.59872318311202*^9}, {3.598724182448244*^9, 3.598724206824198*^9}, {
   3.5987834755754137`*^9, 3.5987835172368917`*^9}, 3.598783553775072*^9, {
   3.598783648841077*^9, 3.598783729877985*^9}, {3.59878378137654*^9, 
   3.5987838738456306`*^9}, {3.598783914606614*^9, 3.598783927916171*^9}, {
   3.598783992597123*^9, 3.598784058120701*^9}, {3.598784090552135*^9, 
   3.598784098287863*^9}, 3.598784350306773*^9, {3.59878464861152*^9, 
   3.598784690963435*^9}, {3.598784967972073*^9, 3.598784971546756*^9}, {
   3.598785061601509*^9, 3.5987850667629747`*^9}, {3.598789962290284*^9, 
   3.598790000126421*^9}, {3.598790208027376*^9, 3.598790210265657*^9}, {
   3.5988774050682907`*^9, 3.5988774247866793`*^9}, 3.598877644632618*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`absorp$$ = 
    0.1, $CellContext`lastlocposszangle$$ = {
    16.52529198687441, -0.19547012481933204`}, $CellContext`lastlocpostzhs$$ \
= {0.5, 0.}, $CellContext`laststartposszangle$$ = {
    16., 0}, $CellContext`laststartpostzhs$$ = {0., 
    0.}, $CellContext`lastszangle$$ = -20.411093978581157`, \
$CellContext`lasttzhs$$ = 0., $CellContext`maxabsorp$$ = 
    0.2, $CellContext`maxszangle$$ = 185., $CellContext`maxtzhs$$ = 
    180., $CellContext`maxxzs$$ = 10, $CellContext`maxyzs$$ = 
    10, $CellContext`minabsorp$$ = 
    0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = -180., \
$CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5604821506268968, $CellContext`radiustzhs$$ =
     0.5, $CellContext`staticpolygons1117419201411610369077098$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
      
      "]]}, $CellContext`staticpolygons1217419201411610369078140$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons1317419201411610369079191$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
      
      "]]}, $CellContext`szangle$$ = -20.411093978581157`, \
$CellContext`tzhs$$ = 0., $CellContext`xoffszangle$$ = 
    0.5252919868744108, $CellContext`xofftzhs$$ = 
    0.5, $CellContext`xszangle$$ = 16.52529198687441, $CellContext`xtzhs$$ = 
    0.5, $CellContext`xzs$$ = 
    0., $CellContext`yoffszangle$$ = -0.19547012481933201`, \
$CellContext`yofftzhs$$ = 
    0., $CellContext`yszangle$$ = -0.19547012481933204`, $CellContext`ytzhs$$ \
= 0., $CellContext`yzs$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`tzhs$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`xzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`szangle$$], 5.}, -175., 185.}, {{
       Hold[$CellContext`absorp$$], 0.1}, 0.001, 0.2}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Style[
        Grid[{{"absorp", 
           InputField[
            Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable1593174192014116103615116490; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
             Dynamic[$CellContext`minabsorp$$], 
             Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable1593174192014116103615116490; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "tzhs", "xzs", "yzs", "szangle", 
               "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xtzhs$$], 0.5}}, {{
       Hold[$CellContext`ytzhs$$], 0.}}, {{
       Hold[$CellContext`radiustzhs$$], 0.5}}, {{
       Hold[$CellContext`xofftzhs$$], 0.5}}, {{
       Hold[$CellContext`yofftzhs$$], 0.}}, {{
       Hold[$CellContext`laststartpostzhs$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpostzhs$$], {0.5, 0.}}}, {{
       Hold[$CellContext`lasttzhs$$], 0}}, {{
       Hold[$CellContext`xszangle$$], 16.498097349045874`}}, {{
       Hold[$CellContext`yszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`radiusszangle$$], 0.5}}, {{
       Hold[$CellContext`xoffszangle$$], 0.4980973490458728}}, {{
       Hold[$CellContext`yoffszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`laststartposszangle$$], {16., 0}}}, {{
       Hold[$CellContext`lastlocposszangle$$], {16.498097349045874`, 
       0.04357787137382908}}}, {{
       Hold[$CellContext`lastszangle$$], 0}}, {{
       Hold[$CellContext`staticpolygons1117419201411610369077098$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1217419201411610369078140$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1317419201411610369079191$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
         "]]}}}}, Typeset`size$$ = {
    816., {433.625, 439.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`tzhs$18720$$ = 
    0, $CellContext`xzs$18725$$ = 0, $CellContext`yzs$18726$$ = 
    0, $CellContext`szangle$18727$$ = 0, $CellContext`absorp$18728$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`absorp$$ = 
        0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
         0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {0.5, 
         0.}, $CellContext`laststartposszangle$$ = {
         16., 0}, $CellContext`laststartpostzhs$$ = {0., 
         0.}, $CellContext`lastszangle$$ = 0, $CellContext`lasttzhs$$ = 
        0, $CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
        185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
        10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
        0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = \
-180., $CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
        0.5, $CellContext`staticpolygons1117419201411610369077098$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
           
           "]]}, $CellContext`staticpolygons1217419201411610369078140$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons1317419201411610369079191$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
           
           "]]}, $CellContext`szangle$$ = 5., $CellContext`tzhs$$ = 
        0., $CellContext`xoffszangle$$ = 
        0.4980973490458728, $CellContext`xofftzhs$$ = 
        0.5, $CellContext`xszangle$$ = 
        16.498097349045874`, $CellContext`xtzhs$$ = 0.5, $CellContext`xzs$$ = 
        0., $CellContext`yoffszangle$$ = 
        0.04357787137382908, $CellContext`yofftzhs$$ = 
        0., $CellContext`yszangle$$ = 
        0.04357787137382908, $CellContext`ytzhs$$ = 0., $CellContext`yzs$$ = 
        0.}, "ControllerVariables" :> {
        Hold[$CellContext`tzhs$$, $CellContext`tzhs$18720$$, 0], 
        Hold[$CellContext`xzs$$, $CellContext`xzs$18725$$, 0], 
        Hold[$CellContext`yzs$$, $CellContext`yzs$18726$$, 0], 
        Hold[$CellContext`szangle$$, $CellContext`szangle$18727$$, 0], 
        Hold[$CellContext`absorp$$, $CellContext`absorp$18728$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[
                 0.8], $CellContext`staticpolygons1117419201411610369077098$$, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons1217419201411610369078140$$, 
                  Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`szangle$$], -
                    Sin[Degree $CellContext`szangle$$]}, {
                    Sin[Degree $CellContext`szangle$$], 
                    Cos[Degree $CellContext`szangle$$]}}, {
                    16., 0}}]], \
$CellContext`staticpolygons1317419201411610369079191$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction117419201411610369082290[$\
CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$], And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]],
                     TrackedSymbols :> {$CellContext`tzhs$$, \
$CellContext`xzs$$, $CellContext`yzs$$, $CellContext`szangle$$}], 
                   SynchronousUpdating -> False]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[If[
                    
                    Or[$CellContext`laststartpostzhs$$ != \
{$CellContext`xzs$$, $CellContext`yzs$$}, $CellContext`lasttzhs$$ =!= \
$CellContext`tzhs$$], $CellContext`laststartpostzhs$$ = {$CellContext`xzs$$, \
$CellContext`yzs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`laststartpostzhs$$, \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$}}, \
({$CellContext`laststartpostzhs$$, {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xtzhs$$, $CellContext`ytzhs$$} != \
$CellContext`lastlocpostzhs$$, $CellContext`lasttzhs$$ != \
$CellContext`tzhs$$], $CellContext`lastlocpostzhs$$ = {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$}), \
({$CellContext`xtzhs$$, $CellContext`ytzhs$$} = #; $CellContext`xofftzhs$$ = \
$CellContext`xtzhs$$ - $CellContext`xzs$$; $CellContext`yofftzhs$$ = \
$CellContext`ytzhs$$ - $CellContext`yzs$$; $CellContext`radiustzhs$$ = 
                    Sqrt[$CellContext`xofftzhs$$^2 + \
$CellContext`yofftzhs$$^2]; $CellContext`tzhs$$ = 
                    Chop[ArcTan[$CellContext`xofftzhs$$, \
$CellContext`yofftzhs$$]/
                    Degree]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["tzhs = ", 
                    ToString[$CellContext`tzhs$$]]]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[
                  
                  If[$CellContext`lastszangle$$ =!= $CellContext`szangle$$, \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`laststartposszangle$$, \
{$CellContext`xszangle$$, $CellContext`yszangle$$}}, \
({$CellContext`laststartposszangle$$, {$CellContext`xszangle$$, \
$CellContext`yszangle$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xszangle$$, $CellContext`yszangle$$} != \
$CellContext`lastlocposszangle$$, $CellContext`lastszangle$$ != \
$CellContext`szangle$$], $CellContext`lastlocposszangle$$ = \
{$CellContext`xszangle$$, $CellContext`yszangle$$}; \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$}), ({$CellContext`xszangle$$, \
$CellContext`yszangle$$} = #; $CellContext`xoffszangle$$ = \
$CellContext`xszangle$$ - 
                    16.; $CellContext`yoffszangle$$ = $CellContext`yszangle$$ + 
                    0; $CellContext`radiusszangle$$ = 
                    Sqrt[$CellContext`xoffszangle$$^2 + \
$CellContext`yoffszangle$$^2]; $CellContext`szangle$$ = 
                    Chop[ArcTan[$CellContext`xoffszangle$$, \
$CellContext`yoffszangle$$]/
                    Degree]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["szangle = ", 
                    ToString[$CellContext`szangle$$]]]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xzs$$, $CellContext`yzs$$}, \
({$CellContext`xzs$$, $CellContext`yzs$$} = Chop[#])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["{xzs, yzs} = ", 
                    ToString[
                    Chop[{$CellContext`xzs$$, $CellContext`yzs$$}]]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "Absorption" -> Dynamic[
             ListPlot3D[
              (Partition[
               Partition[#, 30], 30]& )[
               
               Apply[$CellContext`rayfunction2174192014116103615108296, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$, $CellContext`absorp$$}]], {
              PlotLabel -> "Absorption", PlotRange -> {0, All}, AspectRatio -> 
               1, DataRange -> {{0, 9}, {(-9)/2, 9/2}, {(-9)/2, 9/2}}, Axes -> 
               True, Mesh -> False, ImageSize -> 800}], SynchronousUpdating -> 
             True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`tzhs$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`xzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`yzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`szangle$$, 5.}, -175., 185., 
         ControlType -> None}, {{$CellContext`absorp$$, 0.1}, 0.001, 0.2, 
         ControlType -> None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Style[
         Grid[{{"absorp", 
            InputField[
             Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable1593174192014116103615116490; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
              Dynamic[$CellContext`minabsorp$$], 
              Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable1593174192014116103615116490; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]], {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "tzhs", "xzs", "yzs", "szangle", 
                   "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xtzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`ytzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiustzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xofftzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`yofftzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpostzhs$$, {0., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocpostzhs$$, {0.5, 0.}}, ControlType -> 
         None}, {{$CellContext`lasttzhs$$, 0}, ControlType -> 
         None}, {{$CellContext`xszangle$$, 16.498097349045874`}, ControlType -> 
         None}, {{$CellContext`yszangle$$, 0.04357787137382908}, ControlType -> 
         None}, {{$CellContext`radiusszangle$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xoffszangle$$, 0.4980973490458728}, 
         ControlType -> 
         None}, {{$CellContext`yoffszangle$$, 0.04357787137382908}, 
         ControlType -> 
         None}, {{$CellContext`laststartposszangle$$, {16., 0}}, ControlType -> 
         None}, {{$CellContext`lastlocposszangle$$, {16.498097349045874`, 
          0.04357787137382908}}, ControlType -> 
         None}, {{$CellContext`lastszangle$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons1117419201411610369077098$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons1217419201411610369078140$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1317419201411610369079191$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5}, SynchronousInitialization -> 
        False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {495., 500.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction117419201411610369082290 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukgHN/HY
kouu2+H6nigFd0kx4jKHkPkQ4GB30QGZRuhTQ+MT7250EWMw+IwRbtjFh2q4
MUBpNTQ+8e5GFzkDBm8wwg27+FANNw4orYbGJ97d6CJG4HT1GCPcsIsP1XAT
gNJqaHzi3Y0uYgAOn8sY4YZdfKiGmwiUVkPjE+9u7OIbbIgTH6rhJgGl1dD4
xLsbXcQCkq6IFB+q4SYDpdXQ+MS7G10EEj6PiRQfquGmAKXV0PjEuxtd5AKk
3iRSfKiGmxKUVkPjE+9udBETSDuNSPGhGm4qUFoNjU+8u9FFmMDkDyLFh2q4
qeGgiXc3jAUAwZ8uJw==
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$57}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$57 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$57), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$57, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$57}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17686.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$58}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$58 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$58), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$58, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$58}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17714.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$69}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$69 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$69), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$69, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$69}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17798.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$74}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$74 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$74), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$74, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$74}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17826.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$63}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$63 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$63), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$63, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$63}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17770.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$59}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$59 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$59), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$59, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$59}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17742.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$75}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$75 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$75), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$75, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$75}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 17878.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    17686.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    17714.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    17798.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    17826.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    17770.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    17742.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    17878.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$77}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$77 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$77), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$77, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$77}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18032.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$80 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$80), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$80, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18033.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$77}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$77 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$77), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$77, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$77}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18034.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$80}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$80 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$80), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$80, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$80}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18035.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$79}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 10., Part[#, 2] >= -10., 
                    Part[#, 3] >= -10., Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$79 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$79), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$79, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$79}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18036.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$79}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$79 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$79), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$79, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$79}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18037.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    18032.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    18033.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    18034.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    18035.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    18036.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    18037.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction2174192014116103615108296 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwUENACAMBLAjKJklJJDwxgTCJ4S2te86I8mbAQAAAAAAAD7S1cwCMg==

             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3GdUk4nW8P1gxR4VlUEdY8ceO/bYsceOBY3YsMeO/RIbKmjGij127LEj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                
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$37}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$37 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$37), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$37, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$37}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 13367.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$38}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$38 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$38), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$38, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$38}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 13395.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$52}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$52 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$52), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$52, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$52}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 13479.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$55}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$55 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$55), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$55, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$55}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 13507.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$45}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$45 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$45), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$45, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$45}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 13451.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$41}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$41 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$41), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$41, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$41}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 13423.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$81}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$81 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$81), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$81, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$81}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18071.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    13367.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] Part[$CellContext`XAxis$, 3],
                     -(Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    13561, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13367, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13395, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13479, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13507, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13451, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    13395.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    13561, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13367, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13395, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13479, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13507, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13451, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    13479.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    13561, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13367, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13395, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13479, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13507, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13451, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    13507.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    13561, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13367, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13395, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13479, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13507, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13451, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    13451.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    13561, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13367, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13395, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13479, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13507, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13451, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    13423.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 
                    1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    13561, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13367, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13395, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13479, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13507, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    13451, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    18071.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$88}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$88 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$88), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$88, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$88}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18225.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$90}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$90 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$90), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$90, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$90}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18226.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$88}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$88 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$88), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$88, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$88}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18227.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$90}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$90 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$90), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$90, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$90}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18228.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$89}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$89 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$89), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$89, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$89}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18229.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = Block[{Compile`$89}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$89 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$89), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$89, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$89}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 18230.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    18225.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 
                    1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    18226.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    18227.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    18228.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    18229.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    18230.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 
               2], $CellContext`reportedrays$]; $CellContext`griddata$], \
$CellContext`compileoptionsetting$]]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598878976990816*^9, 3.598879000352447*^9}, {
  3.614739187274494*^9, 3.6147391884192038`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example with ListPlot from 2D data into one-dimensional data using \
CustomDisplayFunction\
\>", "Section",
 CellChangeTimes->{{3.598877088109701*^9, 3.598877116902734*^9}, {
  3.598877167896738*^9, 3.5988771739512253`*^9}, {3.598878249304823*^9, 
  3.598878256766881*^9}, {3.598878418321109*^9, 3.59887842671451*^9}, {
  3.598882019192157*^9, 3.598882028790112*^9}, {3.598882378322294*^9, 
  3.598882381232318*^9}}],

Cell[CellGroupData[{

Cell["\<\
Dimensions[{Table[0.,{30},{30}]}]\
\>", "Input",
 CellChangeTimes->{{3.598877310604426*^9, 3.5988773237174263`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "30", ",", "30"}], "}"}]], "Output",
 CellChangeTimes->{3.598877324130109*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Length[Apply[Join,Table[0.,{30*30}]]]\
\>", "Input",
 CellChangeTimes->{{3.598878010922196*^9, 3.598878019921069*^9}}],

Cell[BoxData["900"], "Output",
 CellChangeTimes->{3.598878020344289*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Options[CustomGrid]", "Input",
 CellChangeTimes->{{3.598878523619816*^9, 3.598878530779101*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TakeFrom", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"CreatedRay", ",", "OriginalRay", ",", "ChangedSurface"}], 
     "}"}]}], ",", 
   RowBox[{"ReplaceFor", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"OriginalRay", ",", "AllCreatedRays", ",", "CreatedRay"}], 
     "}"}]}], ",", 
   RowBox[{"GridCoordinateOffset", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.1`", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"SurfaceID", "\[Rule]", "False"}], ",", 
   RowBox[{"RunningCommentary", "\[Rule]", "False"}], ",", 
   RowBox[{"SymbolicValues", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"EmbedGridData", "\[Rule]", "False"}], ",", 
   RowBox[{"GridOrder", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"GridDimensions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
   RowBox[{"CustomDisplayFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}], ",", 
   RowBox[{"GridFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.598878531035434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gainslab = CustomGrid[SlabPrism[10], griddata, 9, \
SymbolicValues->{griddata->Table[0.,{30*30}],absorp->0.1},
\tGridFunction->Function[griddata[[(#2-1)*30+#1]]=griddata[[(#2-1)*30+#1]]+\
Intensity*Exp[#4*absorp];Intensity = Intensity*Exp[-#4*absorp]], 
\t\tEmbedGridData->True, GridOrder->3, GridDimensions->{1,30,30}, \
ReportedFunction->griddata,CustomDisplayFunction->Function[Partition[\
Partition[#,30],30][[1,15]]],DataRange->{0,9}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.597237958709096*^9, 3.597237996842471*^9}, {
   3.597238330810791*^9, 3.597238335507229*^9}, {3.597238688536249*^9, 
   3.597238707368928*^9}, {3.597239042671205*^9, 3.597239076850318*^9}, {
   3.597239171591176*^9, 3.597239180812758*^9}, {3.5973441527811117`*^9, 
   3.5973442199616823`*^9}, {3.597381816363407*^9, 3.597381881967244*^9}, 
   3.5973823970689163`*^9, {3.59738363048591*^9, 3.597383634595129*^9}, {
   3.5973843277122107`*^9, 3.59738434308495*^9}, {3.597411462492382*^9, 
   3.597411467491835*^9}, {3.597457999497156*^9, 3.597458018967382*^9}, {
   3.597632038733914*^9, 3.597632058548106*^9}, {3.597632217099813*^9, 
   3.597632251225375*^9}, {3.597633026177422*^9, 3.597633037359619*^9}, {
   3.597634057038965*^9, 3.5976340779855013`*^9}, {3.5976354605428457`*^9, 
   3.597635517602868*^9}, 3.597935028617187*^9, {3.5979350824619427`*^9, 
   3.597935114386157*^9}, 3.597935437634905*^9, {3.5979372170759993`*^9, 
   3.597937221426099*^9}, {3.5979437424467907`*^9, 3.597943742789399*^9}, {
   3.597949982146311*^9, 3.597949991221162*^9}, {3.598018682495386*^9, 
   3.598018685071406*^9}, {3.5983586945572042`*^9, 3.5983587019643383`*^9}, {
   3.5986167063493357`*^9, 3.598616708300345*^9}, {3.598616749468322*^9, 
   3.598616781307159*^9}, {3.598616822165442*^9, 3.598616905136224*^9}, {
   3.59861694510306*^9, 3.5986170016457233`*^9}, {3.598617139222601*^9, 
   3.598617172014608*^9}, {3.598617685355007*^9, 3.598617707574271*^9}, {
   3.598617770991014*^9, 3.598617773188614*^9}, {3.5986178250202436`*^9, 
   3.598617990576351*^9}, {3.598618023555862*^9, 3.5986180278039827`*^9}, {
   3.598618096492874*^9, 3.598618104916382*^9}, {3.598618152205185*^9, 
   3.598618265855753*^9}, {3.598618297071982*^9, 3.5986183010146933`*^9}, {
   3.598618331216523*^9, 3.598618331831071*^9}, {3.5986183899972353`*^9, 
   3.598618421563044*^9}, {3.5986185009868507`*^9, 3.5986185068896914`*^9}, {
   3.598618653682613*^9, 3.59861868614471*^9}, {3.598618738921391*^9, 
   3.598618743985243*^9}, 3.5986188285199137`*^9, {3.598618866776342*^9, 
   3.598618867838866*^9}, {3.5986190004339447`*^9, 3.598619028792245*^9}, {
   3.598619362025923*^9, 3.598619365008605*^9}, {3.5986197342580957`*^9, 
   3.598619747121016*^9}, {3.598619955573572*^9, 3.598619962068234*^9}, 
   3.598620032682416*^9, {3.598620156507202*^9, 3.598620164738914*^9}, 
   3.598621062515483*^9, {3.598712813840581*^9, 3.5987128184058523`*^9}, 
   3.598713443321837*^9, {3.598723011077673*^9, 3.598723035051834*^9}, {
   3.5987231973758802`*^9, 3.598723221719447*^9}, {3.5987233556133137`*^9, 
   3.5987233737716017`*^9}, {3.598723669213241*^9, 3.598723676413336*^9}, 
   3.598724248577115*^9, {3.598783578389386*^9, 3.5987835915787992`*^9}, 
   3.598785013378652*^9, {3.5987852234833927`*^9, 3.5987852260575533`*^9}, {
   3.598785463616057*^9, 3.598785495357689*^9}, {3.5987874460655518`*^9, 
   3.598787446568397*^9}, {3.598787518012682*^9, 3.598787518459611*^9}, {
   3.598789641944824*^9, 3.598789646592228*^9}, {3.598790214801388*^9, 
   3.5987902163291597`*^9}, {3.598793356375049*^9, 3.598793367167121*^9}, {
   3.5988771876553164`*^9, 3.598877291486206*^9}, {3.5988773385760393`*^9, 
   3.598877347927306*^9}, {3.598877622810707*^9, 3.598877625841036*^9}, {
   3.59887803227381*^9, 3.598878039716282*^9}, {3.598878436720544*^9, 
   3.598878461521723*^9}, 3.598878535334834*^9, {3.5988820443176413`*^9, 
   3.598882074693902*^9}, {3.5988821364112377`*^9, 3.598882136650394*^9}, {
   3.598882199313205*^9, 3.598882208240498*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"CustomGrid", "[", 
     RowBox[{
      RowBox[{"SlabPrism", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "5"}], ",", 
          RowBox[{"-", "5"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", "griddata", 
      ",", "9", ",", 
      RowBox[{"SymbolicValues", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"absorp", "\[Rule]", "0.1`"}], "}"}]}], ",", 
      RowBox[{"GridFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"griddata", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"#2", "-", "1"}], ")"}], " ", "30"}], "+", "#1"}], 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             RowBox[{"griddata", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#2", "-", "1"}], ")"}], " ", "30"}], "+", "#1"}], 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"Intensity", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"#4", " ", "absorp"}], "]"}]}]}]}], ";", 
           RowBox[{"Intensity", "=", 
            RowBox[{"Intensity", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", "#4"}], " ", "absorp"}], "]"}]}]}]}], ")"}], 
         "&"}], ")"}]}], ",", 
      RowBox[{"EmbedGridData", "\[Rule]", "True"}], ",", 
      RowBox[{"GridOrder", "\[Rule]", "3"}], ",", 
      RowBox[{"GridDimensions", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "30", ",", "30"}], "}"}]}], ",", 
      RowBox[{"ReportedFunction", "\[Rule]", "griddata"}], ",", 
      RowBox[{"CustomDisplayFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Partition", "[", 
             RowBox[{"#1", ",", "30"}], "]"}], ",", "30"}], "]"}], 
          "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "15"}], "\[RightDoubleBracket]"}], "&"}], 
        ")"}]}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{
  3.598785481720141*^9, 3.598787447680771*^9, 3.598787519332398*^9, 
   3.598787787438519*^9, 3.5987893991684237`*^9, {3.598789638608594*^9, 
   3.5987896476037273`*^9}, 3.598789730546843*^9, 3.5987902174790277`*^9, 
   3.598793372623831*^9, 3.5988773617939377`*^9, 3.598877631677249*^9, 
   3.598878083108705*^9, 3.5988784660504017`*^9, 3.598878638086878*^9, 
   3.598878673603629*^9, 3.598878840251976*^9, 3.598878961004806*^9, {
   3.598882063617324*^9, 3.59888207588575*^9}, 3.598882137465218*^9, 
   3.598882209599511*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ManipulateSystem[{Move[LineOfRays[3,NumberOfRays->11],{{xzs,0},{yzs,0.}},{\
tzhs,0}],Resonate[{Move[SlabPrism[10],5],Move[Mirror[{10,10}],16,{szangle,5}]}\
],Boundary[20]},
\t{DynamicFrame[PlotType->TopView],
\tDynamicFrame[PlotType->ListPlot,PlotLabel->\"Absorption\",PlotRange->{0,All}\
,AspectRatio->1,DataRange->{0,9},
\t\tOpticalSystem->{Move[LineOfRays[3,NumberOfRays->2000,MonteCarlo->\
Stratified],{{xzs,0},{yzs,0.}},{tzhs,0}],Resonate[{Move[gainslab,5],Move[\
Mirror[{10,10}],16,{szangle,5}]}],Boundary[20]}]}]\
\>", "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.59861907189555*^9, 3.59861907603083*^9}, {
   3.5986192376173153`*^9, 3.598619243843154*^9}, {3.598619323601527*^9, 
   3.598619326269944*^9}, {3.5986195567035427`*^9, 3.598619644024191*^9}, {
   3.598619848748253*^9, 3.5986198511948767`*^9}, {3.5986200267348623`*^9, 
   3.598620132315246*^9}, {3.598620263843527*^9, 3.598620286210291*^9}, {
   3.5986205657846117`*^9, 3.598620683654751*^9}, {3.598620715446212*^9, 
   3.598620768892735*^9}, 3.598620803614503*^9, 3.5986208399808807`*^9, {
   3.598709580833399*^9, 3.598709610655719*^9}, {3.598713614035285*^9, 
   3.598713641162293*^9}, {3.5987228963934937`*^9, 3.5987229059525223`*^9}, {
   3.598722963206867*^9, 3.59872297836563*^9}, {3.598723162145793*^9, 
   3.59872318311202*^9}, {3.598724182448244*^9, 3.598724206824198*^9}, {
   3.5987834755754137`*^9, 3.5987835172368917`*^9}, 3.598783553775072*^9, {
   3.598783648841077*^9, 3.598783729877985*^9}, {3.59878378137654*^9, 
   3.5987838738456306`*^9}, {3.598783914606614*^9, 3.598783927916171*^9}, {
   3.598783992597123*^9, 3.598784058120701*^9}, {3.598784090552135*^9, 
   3.598784098287863*^9}, 3.598784350306773*^9, {3.59878464861152*^9, 
   3.598784690963435*^9}, {3.598784967972073*^9, 3.598784971546756*^9}, {
   3.598785061601509*^9, 3.5987850667629747`*^9}, {3.598789962290284*^9, 
   3.598790000126421*^9}, {3.598790208027376*^9, 3.598790210265657*^9}, {
   3.5988774050682907`*^9, 3.5988774247866793`*^9}, 3.598877644632618*^9, {
   3.5988820830043364`*^9, 3.598882084298882*^9}, {3.59888224737779*^9, 
   3.59888225059873*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`absorp$$ = 
    0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
    0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {6.838998781028371, 
    0.4744292996453847}, $CellContext`laststartposszangle$$ = {
    16., 0}, $CellContext`laststartpostzhs$$ = {3.5096360685231556`, 
    0.40985476637463414`}, $CellContext`lastszangle$$ = 
    5., $CellContext`lasttzhs$$ = 
    1.1111388885297078`, $CellContext`maxabsorp$$ = 
    0.2, $CellContext`maxszangle$$ = 185., $CellContext`maxtzhs$$ = 
    180., $CellContext`maxxzs$$ = 10, $CellContext`maxyzs$$ = 
    10, $CellContext`minabsorp$$ = 
    0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = -180., \
$CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
    3.3299888801266624`, \
$CellContext`staticpolygons11174732014116113058158692$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
      
      "]]}, $CellContext`staticpolygons12174732014116113058159570$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
      
      "]]}, $CellContext`staticpolygons13174732014116113058160537$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
      "]]}, $CellContext`szangle$$ = 
    5., $CellContext`tzhs$$ = 
    1.1111388885297078`, $CellContext`xoffszangle$$ = 
    0.4980973490458728, $CellContext`xofftzhs$$ = 
    3.3293627125052154`, $CellContext`xszangle$$ = 
    16.498097349045874`, $CellContext`xtzhs$$ = 
    6.838998781028371, $CellContext`xzs$$ = 
    3.5096360685231556`, $CellContext`yoffszangle$$ = 
    0.04357787137382908, $CellContext`yofftzhs$$ = 
    0.06457453327075058, $CellContext`yszangle$$ = 
    0.04357787137382908, $CellContext`ytzhs$$ = 
    0.4744292996453847, $CellContext`yzs$$ = 0.40985476637463414`, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`tzhs$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`xzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`yzs$$], 0.}, -10, 10}, {{
       Hold[$CellContext`szangle$$], 5.}, -175., 185.}, {{
       Hold[$CellContext`absorp$$], 0.1}, 0.001, 0.2}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Style[
        Grid[{{"absorp", 
           InputField[
            Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159317473201411611314198702; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
             Dynamic[$CellContext`minabsorp$$], 
             Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159317473201411611314198702; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`mintzhs$$], -180.}}, {{
       Hold[$CellContext`maxtzhs$$], 180.}}, {{
       Hold[$CellContext`minxzs$$], -10}}, {{
       Hold[$CellContext`maxxzs$$], 10}}, {{
       Hold[$CellContext`minyzs$$], -10}}, {{
       Hold[$CellContext`maxyzs$$], 10}}, {{
       Hold[$CellContext`minszangle$$], -175.}}, {{
       Hold[$CellContext`maxszangle$$], 185.}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {{
       Hold[$CellContext`minabsorp$$], 0.001}}, {{
       Hold[$CellContext`maxabsorp$$], 0.2}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "tzhs", "xzs", "yzs", "szangle", 
               "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
           Optica`Optica`SymbolicRanges -> Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
            ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xtzhs$$], 0.5}}, {{
       Hold[$CellContext`ytzhs$$], 0.}}, {{
       Hold[$CellContext`radiustzhs$$], 0.5}}, {{
       Hold[$CellContext`xofftzhs$$], 0.5}}, {{
       Hold[$CellContext`yofftzhs$$], 0.}}, {{
       Hold[$CellContext`laststartpostzhs$$], {0., 0.}}}, {{
       Hold[$CellContext`lastlocpostzhs$$], {0.5, 0.}}}, {{
       Hold[$CellContext`lasttzhs$$], 0}}, {{
       Hold[$CellContext`xszangle$$], 16.498097349045874`}}, {{
       Hold[$CellContext`yszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`radiusszangle$$], 0.5}}, {{
       Hold[$CellContext`xoffszangle$$], 0.4980973490458728}}, {{
       Hold[$CellContext`yoffszangle$$], 0.04357787137382908}}, {{
       Hold[$CellContext`laststartposszangle$$], {16., 0}}}, {{
       Hold[$CellContext`lastlocposszangle$$], {16.498097349045874`, 
       0.04357787137382908}}}, {{
       Hold[$CellContext`lastszangle$$], 0}}, {{
       Hold[$CellContext`staticpolygons11174732014116113058158692$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons12174732014116113058159570$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons13174732014116113058160537$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
         "]]}}}}, Typeset`size$$ = {
    816., {433.625, 439.375}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`tzhs$110121$$ = 
    0, $CellContext`xzs$110122$$ = 0, $CellContext`yzs$110123$$ = 
    0, $CellContext`szangle$110124$$ = 0, $CellContext`absorp$110125$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`absorp$$ = 
        0.1, $CellContext`lastlocposszangle$$ = {16.498097349045874`, 
         0.04357787137382908}, $CellContext`lastlocpostzhs$$ = {0.5, 
         0.}, $CellContext`laststartposszangle$$ = {
         16., 0}, $CellContext`laststartpostzhs$$ = {0., 
         0.}, $CellContext`lastszangle$$ = 0, $CellContext`lasttzhs$$ = 
        0, $CellContext`maxabsorp$$ = 0.2, $CellContext`maxszangle$$ = 
        185., $CellContext`maxtzhs$$ = 180., $CellContext`maxxzs$$ = 
        10, $CellContext`maxyzs$$ = 10, $CellContext`minabsorp$$ = 
        0.001, $CellContext`minszangle$$ = -175., $CellContext`mintzhs$$ = \
-180., $CellContext`minxzs$$ = -10, $CellContext`minyzs$$ = -10, \
$CellContext`radiusszangle$$ = 0.5, $CellContext`radiustzhs$$ = 
        0.5, $CellContext`staticpolygons11174732014116113058158692$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
           
           "]]}, $CellContext`staticpolygons12174732014116113058159570$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
           
           "]]}, $CellContext`staticpolygons13174732014116113058160537$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
           
           "]]}, $CellContext`szangle$$ = 5., $CellContext`tzhs$$ = 
        0., $CellContext`xoffszangle$$ = 
        0.4980973490458728, $CellContext`xofftzhs$$ = 
        0.5, $CellContext`xszangle$$ = 
        16.498097349045874`, $CellContext`xtzhs$$ = 0.5, $CellContext`xzs$$ = 
        0., $CellContext`yoffszangle$$ = 
        0.04357787137382908, $CellContext`yofftzhs$$ = 
        0., $CellContext`yszangle$$ = 
        0.04357787137382908, $CellContext`ytzhs$$ = 0., $CellContext`yzs$$ = 
        0.}, "ControllerVariables" :> {
        Hold[$CellContext`tzhs$$, $CellContext`tzhs$110121$$, 0], 
        Hold[$CellContext`xzs$$, $CellContext`xzs$110122$$, 0], 
        Hold[$CellContext`yzs$$, $CellContext`yzs$110123$$, 0], 
        Hold[$CellContext`szangle$$, $CellContext`szangle$110124$$, 0], 
        Hold[$CellContext`absorp$$, $CellContext`absorp$110125$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         TabView[{"TopView" -> Show[{
              Graphics[{{
                 Opacity[
                 0.8], $CellContext`staticpolygons11174732014116113058158692$$\
, 
                 
                 GeometricTransformation[$CellContext`\
staticpolygons12174732014116113058159570$$, 
                  Dynamic[BesselJ[1., 3.]; {{{
                    Cos[Degree $CellContext`szangle$$], -
                    Sin[Degree $CellContext`szangle$$]}, {
                    Sin[Degree $CellContext`szangle$$], 
                    Cos[Degree $CellContext`szangle$$]}}, {
                    16., 0}}]], \
$CellContext`staticpolygons13174732014116113058160537$$, 
                 Opacity[1], 
                 RGBColor[
                 0.038747429704798886`, 0.9161617552424038, 
                  0.039847212269181365`], 
                 AbsoluteThickness[Medium], 
                 Line[
                  Dynamic[
                   Refresh[
                    Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction1174732014116113058163287[$\
CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$], And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]],
                     TrackedSymbols :> {$CellContext`tzhs$$, \
$CellContext`xzs$$, $CellContext`yzs$$, $CellContext`szangle$$}], 
                   SynchronousUpdating -> False]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[If[
                    
                    Or[$CellContext`laststartpostzhs$$ != \
{$CellContext`xzs$$, $CellContext`yzs$$}, $CellContext`lasttzhs$$ =!= \
$CellContext`tzhs$$], $CellContext`laststartpostzhs$$ = {$CellContext`xzs$$, \
$CellContext`yzs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`laststartpostzhs$$, \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$}}, \
({$CellContext`laststartpostzhs$$, {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xtzhs$$, $CellContext`ytzhs$$} != \
$CellContext`lastlocpostzhs$$, $CellContext`lasttzhs$$ != \
$CellContext`tzhs$$], $CellContext`lastlocpostzhs$$ = {$CellContext`xtzhs$$, \
$CellContext`ytzhs$$}; $CellContext`lasttzhs$$ = $CellContext`tzhs$$; \
{$CellContext`xtzhs$$, $CellContext`ytzhs$$} = \
$CellContext`laststartpostzhs$$ + $CellContext`radiustzhs$$ {
                    Cos[$CellContext`tzhs$$ Degree], 
                    
                    Sin[$CellContext`tzhs$$ 
                    Degree]}]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$}), \
({$CellContext`xtzhs$$, $CellContext`ytzhs$$} = #; $CellContext`xofftzhs$$ = \
$CellContext`xtzhs$$ - $CellContext`xzs$$; $CellContext`yofftzhs$$ = \
$CellContext`ytzhs$$ - $CellContext`yzs$$; $CellContext`radiustzhs$$ = 
                    Sqrt[$CellContext`xofftzhs$$^2 + \
$CellContext`yofftzhs$$^2]; $CellContext`tzhs$$ = 
                    Chop[ArcTan[$CellContext`xofftzhs$$, \
$CellContext`yofftzhs$$]/
                    Degree]; {$CellContext`xtzhs$$, $CellContext`ytzhs$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["tzhs = ", 
                    ToString[$CellContext`tzhs$$]]]], 
                 Arrowheads[Large], 
                 Thickness[Large], 
                 Dashing[{Small, Small}], 
                 RGBColor[1, 1, 0], 
                 Arrow[
                  Dynamic[
                  If[$CellContext`lastszangle$$ =!= $CellContext`szangle$$, \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`laststartposszangle$$, \
{$CellContext`xszangle$$, $CellContext`yszangle$$}}, \
({$CellContext`laststartposszangle$$, {$CellContext`xszangle$$, \
$CellContext`yszangle$$}} = #)& ]], 
                 Tooltip[
                  Locator[
                   Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xszangle$$, $CellContext`yszangle$$} != \
$CellContext`lastlocposszangle$$, $CellContext`lastszangle$$ != \
$CellContext`szangle$$], $CellContext`lastlocposszangle$$ = \
{$CellContext`xszangle$$, $CellContext`yszangle$$}; \
$CellContext`lastszangle$$ = $CellContext`szangle$$; \
{$CellContext`xszangle$$, $CellContext`yszangle$$} = \
$CellContext`laststartposszangle$$ + $CellContext`radiusszangle$$ {
                    Cos[$CellContext`szangle$$ Degree], 
                    
                    Sin[$CellContext`szangle$$ 
                    Degree]}]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$}), ({$CellContext`xszangle$$, \
$CellContext`yszangle$$} = #; $CellContext`xoffszangle$$ = \
$CellContext`xszangle$$ - 
                    16.; $CellContext`yoffszangle$$ = $CellContext`yszangle$$ + 
                    0; $CellContext`radiusszangle$$ = 
                    Sqrt[$CellContext`xoffszangle$$^2 + \
$CellContext`yoffszangle$$^2]; $CellContext`szangle$$ = 
                    Chop[ArcTan[$CellContext`xoffszangle$$, \
$CellContext`yoffszangle$$]/
                    Degree]; {$CellContext`xszangle$$, \
$CellContext`yszangle$$})& ], 
                   Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["szangle = ", 
                    ToString[$CellContext`szangle$$]]]], 
                 Tooltip[
                  Locator[
                   Dynamic[
                   BesselJ[
                    1., 3.]; {$CellContext`xzs$$, $CellContext`yzs$$}, \
({$CellContext`xzs$$, $CellContext`yzs$$} = Chop[#])& ], 
                   Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                  Dynamic[
                   StringJoin["{xzs, yzs} = ", 
                    ToString[
                    Chop[{$CellContext`xzs$$, $CellContext`yzs$$}]]]]]}}]}, {
             PlotLabel -> "TopView", ImageSize -> 800, AspectRatio -> 
              Automatic}], "Absorption" -> Dynamic[
             ListPlot[
              (Part[
               Partition[
                Partition[#, 30], 30], 1, 15]& )[
               
               Apply[$CellContext`rayfunction217473201411611314190940, \
{$CellContext`tzhs$$, $CellContext`xzs$$, $CellContext`yzs$$, \
$CellContext`szangle$$, $CellContext`absorp$$}]], {
              PlotLabel -> "Absorption", PlotRange -> {0, All}, AspectRatio -> 
               1, DataRange -> {0, 9}, Frame -> True, Axes -> True, Mesh -> 
               False, ImageSize -> 800, Joined -> True}], SynchronousUpdating -> 
             True]}, 1], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`tzhs$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`xzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`yzs$$, 0.}, -10, 10, 
         ControlType -> None}, {{$CellContext`szangle$$, 5.}, -175., 185., 
         ControlType -> None}, {{$CellContext`absorp$$, 0.1}, 0.001, 0.2, 
         ControlType -> None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Style[
         Grid[{{"absorp", 
            InputField[
             Dynamic[$CellContext`minabsorp$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159317473201411611314198702; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ], {
              Dynamic[$CellContext`minabsorp$$], 
              Dynamic[$CellContext`maxabsorp$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxabsorp$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159317473201411611314198702; $CellContext`absorp$$, \
($CellContext`absorp$$ = #)& ]}}]], {{$CellContext`minabsorp$$, 0.001}, 
         ControlType -> None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`mintzhs$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxtzhs$$, 180.}, ControlType -> 
         None}, {{$CellContext`minxzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxxzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minyzs$$, -10}, ControlType -> 
         None}, {{$CellContext`maxyzs$$, 10}, ControlType -> 
         None}, {{$CellContext`minszangle$$, -175.}, ControlType -> 
         None}, {{$CellContext`maxszangle$$, 185.}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> 
         None}, {{$CellContext`minabsorp$$, 0.001}, ControlType -> 
         None}, {{$CellContext`maxabsorp$$, 0.2}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "tzhs", "xzs", "yzs", "szangle", 
                "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}], 
            Optica`Optica`SymbolicRanges -> Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "tzhs", "xzs", "yzs", "szangle", 
                  "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[3, NumberOfRays -> 11], {{xzs, 0}, {yzs, 0}}, \
{tzhs, 0.}, SymbolicValues -> {tzhs -> 0, xzs -> 0., yzs -> 0.}], \
Resonate[{Move[SlabPrism[{0, -5, -5}, {10, 5, 5}], 5.], Move[Mirror[{10, \
10}], 16., {szangle, 4.999999999999999}, SymbolicValues -> {szangle -> 5}]}], \
Boundary[{0, -10, -10}, {20, 10, 10}]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "tzhs", "xzs", "yzs", "szangle", 
                 "absorp"}, {$CellContext`tzhs$$, $CellContext`xzs$$, \
$CellContext`yzs$$, $CellContext`szangle$$, $CellContext`absorp$$}}]], 
             ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "tzhs", "xzs", "yzs", "szangle", 
                   "absorp"}, {$CellContext`mintzhs$$, $CellContext`minxzs$$, \
$CellContext`minyzs$$, $CellContext`minszangle$$, $CellContext`minabsorp$$}, \
{$CellContext`maxtzhs$$, $CellContext`maxxzs$$, $CellContext`maxyzs$$, \
$CellContext`maxszangle$$, $CellContext`maxabsorp$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xtzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`ytzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiustzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xofftzhs$$, 0.5}, ControlType -> 
         None}, {{$CellContext`yofftzhs$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartpostzhs$$, {0., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocpostzhs$$, {0.5, 0.}}, ControlType -> 
         None}, {{$CellContext`lasttzhs$$, 0}, ControlType -> 
         None}, {{$CellContext`xszangle$$, 16.498097349045874`}, ControlType -> 
         None}, {{$CellContext`yszangle$$, 0.04357787137382908}, ControlType -> 
         None}, {{$CellContext`radiusszangle$$, 0.5}, ControlType -> 
         None}, {{$CellContext`xoffszangle$$, 0.4980973490458728}, 
         ControlType -> 
         None}, {{$CellContext`yoffszangle$$, 0.04357787137382908}, 
         ControlType -> 
         None}, {{$CellContext`laststartposszangle$$, {16., 0}}, ControlType -> 
         None}, {{$CellContext`lastlocposszangle$$, {16.498097349045874`, 
          0.04357787137382908}}, ControlType -> 
         None}, {{$CellContext`lastszangle$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons11174732014116113058158692$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAERByh9AI1PiEZXD+XroanTwyVPSD0O/UTb
j4OP7g9C9hOiCfmHUPgRHR7o7kfnY7gfAGhyHoo=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons12174732014116113058159570$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQAciB2Cs1atAQACNz3UAVT0LnL8GLP9rP4y/
Acx/tZ8BB1gBkbdH5f+C8//9BwFmB1R5Ljh/FcR9cD7U/Tj5q9HUr0YzD+of
OH8Nmns2oLkXh3/2o/IR4QH1zwE0/8D5q9DCG+p+DD4At6tipw==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons13174732014116113058160537$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigAETBwit4oDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4ACnMcMg==
            "]]}}, ControlType -> 
         None}}, "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5}, SynchronousInitialization -> 
        False, SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{861., {495., 500.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction1174732014116113058163287 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + 
                   $CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ \
$CellContext`symr2$ + $CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ \
$CellContext`symr8$, $CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ \
$CellContext`symr6$ + $CellContext`r3$ $CellContext`symr9$}; \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$} = \
{$CellContext`r4$ $CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + \
$CellContext`r6$ $CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + \
$CellContext`r5$ $CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, \
$CellContext`r4$ $CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + \
$CellContext`r6$ $CellContext`symr9$}; {$CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$} = {$CellContext`r7$ \
$CellContext`symr1$ + $CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ \
$CellContext`symr7$, $CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ \
$CellContext`symr5$ + $CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ \
$CellContext`symr3$ + $CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ \
$CellContext`symr9$}; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
{{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}, \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$}, \
{$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$}}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGDgBmJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukgHN/HY
kouu2+H6nigFd0kx4jKHkPkQkLDglwMyjdCnhsYn3t3oIsZg8Bkj3LCLD9Vw
Y4DSamh84t2NLnIGDN5ghBt28aEabhxQWg2NT7y70UWMwOnqMUa4YRcfquEm
AKXV0PjEuxtdxAAcPpcxwg27+FANNxEorYbGJ97d2MU32BAnPlTDTQJKq6Hx
iXc3uogFJF0RKT5Uw00GSquh8Yl3N7oIJHweEyk+VMNNAUqrofGJdze6yAVI
vUmk+FANNyUorYbGJ97d6CImkHYakeJDNdxUoLQaGp94d6OLMIHJH0SKD9Vw
U8NBE+9uGAsAUZg82Q==
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$185}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$185 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$185), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$185, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$185}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109091.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$186}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$186 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$186), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$186, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$186}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109119.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$189}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$189 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$189), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$189, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$189}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109203.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$190}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$190 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$190), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$190, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$190}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109231.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$188}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    
                    Compile`$188 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$188), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$188, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$188}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109175.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$187}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$187 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$187), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$187, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$187}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109147.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$191}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$191 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$191), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$191, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$191}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109283.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    109091.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    109119.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    109203.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    109231.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    109175.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    109147.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    109283.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$192}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$192 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$192), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$192, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$192}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109437.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$194}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$194 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$194), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$194, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$194}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109438.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$192}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$192 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$192), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$192, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$192}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109439.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$194}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$194 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$194), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$194, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$194}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109440.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$193}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$193 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$193), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$193, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$193}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109441.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$193}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$193 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$193), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$193, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$193}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109442.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    109437.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    109438.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    109439.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    109440.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    109441.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    109442.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`rayfunction217473201411611314190940 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`tzhs$$, 
            Blank[Real]}, {$CellContext`xzs$$, 
            Blank[Real]}, {$CellContext`yzs$$, 
            Blank[Real]}, {$CellContext`szangle$$, 
            Blank[Real]}, {$CellContext`absorp$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`gcx$, $CellContext`gcy$, \
$CellContext`gcz$, $CellContext`gdimx$, $CellContext`gdimy$, \
$CellContext`gdimz$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`gintercepts$, \
$CellContext`gmaxlength$, $CellContext`gmm$, $CellContext`gnn$, \
$CellContext`goo$, $CellContext`griddata$, $CellContext`grr$, \
$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$, \
$CellContext`grtx$, $CellContext`grty$, $CellContext`grtz$, \
$CellContext`gspacex$, $CellContext`gspacey$, $CellContext`gspacez$, \
$CellContext`gu$, $CellContext`gv$, $CellContext`gw$, $CellContext`gxave$, \
$CellContext`gyave$, $CellContext`gzave$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`listofpositions$, $CellContext`localdummyoutrayspresent$, \
$CellContext`localendingpoint$, $CellContext`localendpos$, \
$CellContext`localindex$, $CellContext`localintensity$, \
$CellContext`localopticallength$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`localpos$, \
$CellContext`localraylength$, $CellContext`localrotation$, \
$CellContext`localstartingpoint$, $CellContext`localstartpos$, \
$CellContext`localtilt$, $CellContext`localtranslation$, \
$CellContext`magnitude$, $CellContext`maxclonegenerationnumber$, \
$CellContext`maximumposition$, $CellContext`minimumraylength$, \
$CellContext`minresonateraylength$, $CellContext`n12$, \
$CellContext`newcomponentnumber$, $CellContext`newdeflectedrays$, \
$CellContext`newdistance$, $CellContext`newpos$, $CellContext`newsurfaceid$, \
$CellContext`newsurfacenumber$, $CellContext`newtilt$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`surfrot$, $CellContext`surftrans$, \
$CellContext`symr1$, $CellContext`symr2$, $CellContext`symr3$, \
$CellContext`symr4$, $CellContext`symr5$, $CellContext`symr6$, \
$CellContext`symr7$, $CellContext`symr8$, $CellContext`symr9$, \
$CellContext`tempclonedata$, $CellContext`terminatedeflection$, \
$CellContext`thresholdintensity$, $CellContext`tiltmagnitude$, \
$CellContext`transmatrix$, $CellContext`LocTV1$, $CellContext`LocTV10$, \
$CellContext`LocTV2$, $CellContext`LocTV3$, $CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$, $CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$, $CellContext`u$, \
$CellContext`unfilteredintersections$, $CellContext`unit$, $CellContext`uu$, \
$CellContext`ver$, $CellContext`wavelength$, $CellContext`XAxis$, \
$CellContext`xunit$, $CellContext`YAxis$, $CellContext`yunit$, \
$CellContext`ZAxis$, $CellContext`zunit$}, $CellContext`rsx$ = 
            1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`griddata$ = CompressedData["
1:eJztwUENACAMBLAjKJklJJDwxgTCJ4S2te86I8mbAQAAAAAAAD7S1cwCMg==

             "]; $CellContext`localstartingpoint$ = {0., 0., 
             0.}; $CellContext`localendingpoint$ = {0., 0., 
             0.}; $CellContext`localtilt$ = {1., 0., 
             0.}; $CellContext`surftrans$ = {1., 0., 
             0.}; $CellContext`surfrot$ = {{
             1.}}; $CellContext`listofpositions$ = {{
             1.}}; $CellContext`gintercepts$ = {{
             1.}}; $CellContext`localopticallength$ = 
            0.; $CellContext`localtranslation$ = {1., 0., 
             0.}; $CellContext`localrotation$ = {{
             1.}}; $CellContext`localintensity$ = 
            1.; $CellContext`localindex$ = 1.; $CellContext`gspacex$ = 
            1.; $CellContext`gspacey$ = 1.; $CellContext`gspacez$ = 
            1.; $CellContext`gxave$ = 1.; $CellContext`gyave$ = 
            1.; $CellContext`gzave$ = 1.; $CellContext`localraylength$ = 
            0.; $CellContext`newpos$ = {0., 0., 0.}; $CellContext`newtilt$ = {
             1., 0., 0.}; $CellContext`localpos$ = {0., 0., 
             0.}; $CellContext`localstartpos$ = {0., 0., 
             0.}; $CellContext`localendpos$ = {0., 0., 
             0.}; $CellContext`grsx$ = 1.; $CellContext`grsy$ = 
            1.; $CellContext`grsz$ = 1.; $CellContext`grtx$ = 
            1.; $CellContext`grty$ = 1.; $CellContext`grtz$ = 
            1.; $CellContext`gcx$ = 1.; $CellContext`gcy$ = 
            1.; $CellContext`gcz$ = 1.; $CellContext`gdimx$ = 
            1.; $CellContext`gdimy$ = 1.; $CellContext`gdimz$ = 
            1.; $CellContext`gu$ = 1.; $CellContext`gv$ = 
            1.; $CellContext`gw$ = 1.; $CellContext`gnn$ = 
            1; $CellContext`gmm$ = 1; $CellContext`goo$ = 
            1; $CellContext`grr$ = 1.; $CellContext`gmaxlength$ = 
            1.; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`tzhs$$], 
                  Sin[Degree $CellContext`tzhs$$], 0, -
                  Sin[Degree $CellContext`tzhs$$], 
                  Cos[Degree $CellContext`tzhs$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`xzs$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`yzs$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJzU3GV0kwm36PHgZShD8OLB2uJBpwz24MWDFw9ePHjxh2LFg07x4EUbvHiA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                
                "]]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 
            0.; ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$} = Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$165}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$165 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$165), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$165, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$165}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 90736.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$166}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$166 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$166), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$166, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$166}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 90764.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$169}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$169 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$169), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$169, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$169}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 90848.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$170}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$170 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$170), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$170, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$170}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 90876.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$168}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$168 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$168), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$168, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$168}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 90820.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$167}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5.0024999999999995`, 
                    Part[#, 2] >= -5.0024999999999995`, 
                    Part[#, 3] >= -5.0024999999999995`, Part[#, 3] <= 
                    5.0024999999999995`]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$167 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$167), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$167, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$167}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 90792.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$195}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                    Part[#, 3] <= 5.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$195 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$195), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$195, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$195}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109476.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -5. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    90736.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    5. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    5., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    90930, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90736, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90764, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90848, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90876, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90820, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-15. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    90764.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    15. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    15., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    90930, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90736, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90764, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90848, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90876, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90820, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    90848.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -5. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    90930, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90736, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90764, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90848, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90876, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90820, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    90876.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 5., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    90930, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90736, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90764, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90848, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90876, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90820, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    5. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    90820.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -5. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    90930, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90736, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90764, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90848, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90876, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90820, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-5. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    90792.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    5. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 5.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - (
                    2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]; \
$CellContext`deflectedrays$ = $CellContext`allcreatedrays$; \
$CellContext`newdeflectedrays$ = {$CellContext`originalray$}; 
                    Scan[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; ($CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; \
$CellContext`surftrans$ = $CellContext`surfacetranslationvector$; \
$CellContext`surfrot$ = $CellContext`surfacerotationmatrix$; 
                    Which[$CellContext`surfaceid$ == 
                    90930, $CellContext`localtranslation$ = {0., 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90736, $CellContext`localtranslation$ = {-0.1, 0., 
                    0.}; $CellContext`localrotation$ = {{1., 0., 0.}, {0., 1.,
                     0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90764, $CellContext`localtranslation$ = {9.9, 0., 
                    0.}; $CellContext`localrotation$ = {{-1., 0., 0.}, {
                    0., -1., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90848, $CellContext`localtranslation$ = {4.9, -5., 
                    0.}; $CellContext`localrotation$ = {{0., 1., 0.}, {-1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90876, $CellContext`localtranslation$ = {4.9, 5., 
                    0.}; $CellContext`localrotation$ = {{0., -1., 0.}, {1., 
                    0., 0.}, {0., 0., 1.}}, $CellContext`surfaceid$ == 
                    90820, $CellContext`localtranslation$ = {4.9, 
                    0., -5.}; $CellContext`localrotation$ = {{0., 0., 1.}, {
                    0., 1., 0.}, {-1., 0., 0.}}, 
                    True, $CellContext`localtranslation$ = {4.9, 0., 
                    5.}; $CellContext`localrotation$ = {{0., 0., -1.}, {
                    0., -1., 0.}, {-1., 0., 
                    0.}}]; {$CellContext`gdimz$, $CellContext`gdimy$, \
$CellContext`gdimx$} = {1., 30., 30.}; $CellContext`localstartingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$} - $CellContext`surftrans$]; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$} - $CellContext`surftrans$]; \
$CellContext`localtilt$ = 
                    Dot[$CellContext`surfrot$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`localintensity$ = \
$CellContext`intensity$; $CellContext`localindex$ = 
                    Sqrt[2.2718929 + 4.9240991*^-7/$CellContext`wavelength$^8 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    0.00020816965/$CellContext`wavelength$^4 + 
                    0.010592509/$CellContext`wavelength$^2 - 
                    0.010108077 $CellContext`wavelength$^2]; 
                    If[Part[$CellContext`originalray$, 
                    20] == $CellContext`localindex$, \
$CellContext`localstartingpoint$ = 
                    Dot[$CellContext`localstartingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`localendingpoint$ = 
                    Dot[$CellContext`localendingpoint$, \
$CellContext`localrotation$] + $CellContext`localtranslation$; \
$CellContext`gmaxlength$ = Sqrt[
                    
                    Dot[$CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$, $CellContext`localendingpoint$ - \
$CellContext`localstartingpoint$]]; $CellContext`localtilt$ = 
                    Dot[$CellContext`localtilt$, $CellContext`localrotation$]; \
{$CellContext`grsx$, $CellContext`grsy$, $CellContext`grsz$} = \
$CellContext`localstartingpoint$; {$CellContext`grtx$, $CellContext`grty$, \
$CellContext`grtz$} = $CellContext`localtilt$; {$CellContext`gcx$, \
$CellContext`gcy$, $CellContext`gcz$} = {
                    0, ((-9)/2 + 9/2)/2, ((-9)/2 + 9/2)/
                    2}; $CellContext`gspacex$ = 
                    Plus[9]/$CellContext`gdimx$; $CellContext`gspacey$ = (
                    9/2 - (-9)/
                    2)/$CellContext`gdimy$; $CellContext`gspacez$ = (
                    9/2 - (-9)/2)/$CellContext`gdimz$; $CellContext`gxave$ = 
                    Plus[9]/2; $CellContext`gyave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gzave$ = ((-9)/2 + 9/2)/
                    2; $CellContext`gintercepts$ = Join[
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtx$] > 
                    1.*^-6, $CellContext`gu$ = $CellContext`gcx$ + \
$CellContext`gspacex$ $CellContext`indexx; $CellContext`gv$ = \
-$CellContext`gcy$ + $CellContext`grsy$ - ((-$CellContext`gcx$ - \
$CellContext`gspacex$ $CellContext`indexx + $CellContext`grsx$) \
$CellContext`grty$)/$CellContext`grtx$; $CellContext`gw$ = -$CellContext`gcz$ + \
$CellContext`grsz$ - ((-$CellContext`gcx$ - $CellContext`gspacex$ \
$CellContext`indexx + $CellContext`grsx$) \
$CellContext`grtz$)/$CellContext`grtx$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, \
$CellContext`indexx, ($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, ($CellContext`gw$ - (-9)/
                    2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}], {$CellContext`indexx, 
                    0, $CellContext`gdimx$, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 3] >= (-9)/2, Part[#, 3] <= 9/2, 
                    Part[#, 4] >= (-9)/2, Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grty$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcy$ - $CellContext`gspacey$ \
$CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtx$)/$CellContext`grty$; $CellContext`gv$ = $CellContext`gcy$ + \
$CellContext`gspacey$ $CellContext`indexy; $CellContext`gw$ = \
-$CellContext`gcz$ + $CellContext`grsz$ - ((-$CellContext`gcy$ - \
$CellContext`gspacey$ $CellContext`indexy + $CellContext`grsy$) \
$CellContext`grtz$)/$CellContext`grty$; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
$CellContext`indexy + ($CellContext`gdimy$ - 1.)/2. + 
                    0.5, ($CellContext`gw$ - (-9)/2)/$CellContext`gspacez$}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexy, -(($CellContext`gdimy$ - 1)/
                    2) - 0.5, ($CellContext`gdimy$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 4] >= (-9)/2, 
                    Part[#, 4] <= 9/2]& ], 
                    Select[
                    Join[
                    Table[
                    If[
                    Abs[$CellContext`grtz$] > 
                    1.*^-6, $CellContext`gu$ = -$CellContext`gcx$ + \
$CellContext`grsx$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grtx$)/$CellContext`grtz$; $CellContext`gv$ = -$CellContext`gcy$ + \
$CellContext`grsy$ - ((-$CellContext`gcz$ - $CellContext`gspacez$ \
$CellContext`indexz + $CellContext`grsz$) \
$CellContext`grty$)/$CellContext`grtz$; $CellContext`gw$ = $CellContext`gcz$ + \
$CellContext`gspacez$ $CellContext`indexz; {
                    
                    Sqrt[($CellContext`gu$ - $CellContext`grsx$)^2 + \
($CellContext`gv$ - $CellContext`grsy$)^2 + ($CellContext`gw$ - \
$CellContext`grsz$)^2], $CellContext`gu$, $CellContext`gv$, $CellContext`gw$, 
                    Plus[$CellContext`gu$]/$CellContext`gspacex$, \
($CellContext`gv$ - (-9)/
                    2)/$CellContext`gspacey$, $CellContext`indexz + \
($CellContext`gdimz$ - 1)/2 + 0.5}, {
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 
                    0.}], {$CellContext`indexz, -(($CellContext`gdimz$ - 1)/
                    2) - 0.5, ($CellContext`gdimz$ - 1)/2 + 0.5, 1}], {{
                    0., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}], And[
                    Part[#, 2] >= 0, Part[#, 2] <= 9, Part[#, 3] >= (-9)/2, 
                    Part[#, 3] <= 9/2]& ], {{
                    1., $CellContext`gxave$, $CellContext`gyave$, \
$CellContext`gzave$, 0., 0., 0.}}]; $CellContext`gintercepts$ = 
                    Select[$CellContext`gintercepts$, Or[
                    And[
                    Part[#, 1] > 1.*^-7, 
                    Part[#, 1] <= $CellContext`gmaxlength$], Part[#, 1] == 
                    1.]& ]; If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = Sort[
                    
                    Drop[$CellContext`gintercepts$, -1]], \
$CellContext`gintercepts$ = {{0., 0., 0., 0., 0., 0., 0.}}]; 
                    If[Length[$CellContext`gintercepts$] > 
                    1, $CellContext`gintercepts$ = MapThread[Join[N[
                    Floor[(Part[#, {5, 6, 7}] + Part[#2, {5, 6, 7}])/2.]] + {
                    1., 1., 1.}, {Part[#2, 1] - Part[#, 1]}, {
                    Part[#, 2], 
                    Part[#, 3], 
                    Part[#, 4], 
                    Part[#2, 2], 
                    Part[#2, 3], 
                    Part[#2, 4]}]& , {
                    Drop[$CellContext`gintercepts$, -1], 
                    
                    Rest[$CellContext`gintercepts$]}]; \
$CellContext`gintercepts$ = Select[
                    
                    Join[$CellContext`gintercepts$, {{0., 0., 0., 1., 0., 0., 
                    0., 0., 0., 0.}}], Part[#, 4] > 1.*^-7& ]; 
                    If[Length[$CellContext`gintercepts$] == 
                    1, $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, Map[($CellContext`gnn$ = 
                    Floor[Part[#, 1] + 0.5]; $CellContext`gmm$ = 
                    Floor[Part[#, 2] + 0.5]; $CellContext`goo$ = 
                    Floor[Part[#, 3] + 0.5]; $CellContext`grr$ = 
                    Part[#, 4]; ((Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] = Part[$CellContext`griddata$, (#2 - 1) 
                    30 + #] + $CellContext`intensity$ 
                    Exp[#4 $CellContext`absorp$$]; $CellContext`intensity$ = \
$CellContext`intensity$ 
                    Exp[-(#4 $CellContext`absorp$$)])& )[$CellContext`gnn$, \
$CellContext`gmm$, $CellContext`goo$, $CellContext`grr$, 
                    Part[#, 5], 
                    Part[#, 6], 
                    Part[#, 7], 
                    Part[#, 8], 
                    Part[#, 9], 
                    Part[#, 10]]; 1.)& , 
                    
                    Drop[$CellContext`gintercepts$, -1]]; \
$CellContext`allcreatedrays$ = {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}], $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
$CellContext`newdeflectedrays$ = 
                    Join[$CellContext`newdeflectedrays$, \
$CellContext`allcreatedrays$])& , $CellContext`deflectedrays$]; \
$CellContext`allcreatedrays$ = 
                    Drop[$CellContext`newdeflectedrays$, 
                    1]; $CellContext`deflectedrays$ = \
$CellContext`allcreatedrays$; $CellContext`deflectedrays$ = 
                    MapIndexed[ReplacePart[#, 
                    First[#2], 
                    34]& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = $CellContext`deflectedrays$); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, $CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`r2$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`yunit$ = $CellContext`r2$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`r1$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = (-16. + \
$CellContext`rex$) Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rey$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`ry$ = $CellContext`rey$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. (-16. + $CellContext`rex$)) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    109476.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    16. + $CellContext`rxhlp$ Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]] - (
                    1. $CellContext`ryhlp$) Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rey$ = $CellContext`ryhlp$ Re[
                    Cos[
                    0.017453292519943295` $CellContext`szangle$$]] + \
$CellContext`rxhlp$ Re[
                    Sin[
                    0.017453292519943295` $CellContext`szangle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` $CellContext`szangle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`szangle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`localdummyoutrayspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = Map[Dot[{{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], -Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    0.}, {-Re[
                    Sin[0.017453292519943295` $CellContext`szangle$$]], 
                    Re[
                    Cos[0.017453292519943295` $CellContext`szangle$$]], 0.}, {
                    0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    16., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + \
(Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$})
                     Exp[(I $CellContext`pol3$) 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - (2 $CellContext`ZAxis$) 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    OpticaTools`Numerics`NP[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGBgAmJGIFZngIEP9gNHN0SY5J89SJx6uHv346AH0B/0podm
uAEAvnFifw==
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]); $CellContext`inrays$ = \
$CellContext`deflectedlocalrays$; $CellContext`propagate$ = \
$CellContext`generationnumber$ < $CellContext`generationlimit$]; \
$CellContext`propagatedrays$ = If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$196}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$196 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$196), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$196, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$196}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109630.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$198}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$198 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$198), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$198, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$198}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109631.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$196}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$196 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$196), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$196, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$196}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109632.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$198}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$198 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$198), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$198, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$198}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109633.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$197}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$197 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$197), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$197, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$197}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109634.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$197}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 10., Part[#, 2] >= -10., Part[#, 3] >= -10.,
                     Part[#, 3] <= 10.]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$197 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$197), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$197, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$197}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 109635.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r1$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-20. + \
$CellContext`rex$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    109630.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20. - 1. $CellContext`rxhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-1., 0., 0.}, {0., -1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20., 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rey$; $CellContext`ry$ = -(-10. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    109631.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`ryhlp$; $CellContext`rey$ = -10. + \
$CellContext`rxhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., -10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 3., 
                    109632.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r2$; $CellContext`yunit$ = \
$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rey$); $CellContext`ry$ = -10. + $CellContext`rex$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 4., 
                    
                    109633.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. + $CellContext`ryhlp$; $CellContext`rey$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    10., 10., 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    10. + $CellContext`rez$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = -(-10. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 5., 
                    
                    109634.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = -10. + $CellContext`rxhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, -10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = -$CellContext`r3$; $CellContext`yunit$ = \
-$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -(-10. + \
$CellContext`rez$); $CellContext`ry$ = -$CellContext`rey$; $CellContext`rz$ = \
-(-10. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 6., 
                    
                    109635.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    10. - 1. $CellContext`rzhlp$; $CellContext`rey$ = \
-$CellContext`ryhlp$; $CellContext`rez$ = 
                    10. - 1. $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., -1., 0.}, {-1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., -1.}, {0., -1., 0.}, {-1., 0.,
                     0.}}; $CellContext`surfacetranslationvector$ = {
                    10., 0, 10.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}); {$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 
               2], $CellContext`reportedrays$]; $CellContext`griddata$], \
$CellContext`compileoptionsetting$]]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.598878976990816*^9, 3.598879000352447*^9}, {
  3.598882102678492*^9, 3.598882108921296*^9}, {3.598882152994039*^9, 
  3.598882159667787*^9}, {3.598882225196403*^9, 3.598882231269813*^9}, {
  3.598882266043359*^9, 3.5988822726937437`*^9}, {3.598882308271132*^9, 
  3.598882350467759*^9}, {3.598882392640712*^9, 3.598882393424718*^9}, {
  3.614739183372492*^9, 3.6147391844748507`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1588, 1121},
WindowMargins->{{-12, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3598858993-9948643"->{
  Cell[678, 25, 1936, 27, 249, "Print",
   CellTags->"Info3598858993-9948643"]},
 "Info3598858995-9948643"->{
  Cell[2750, 60, 1645, 23, 181, "Print",
   CellTags->"Info3598858995-9948643"]},
 "Info3598859911-8864466"->{
  Cell[4538, 91, 1525, 22, 194, "Print",
   CellTags->"Info3598859911-8864466"]},
 "Info3598857435-2171160"->{
  Cell[6196, 121, 1266, 18, 131, "Print",
   CellTags->"Info3598857435-2171160"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3598858993-9948643", 5584240, 93035},
 {"Info3598858995-9948643", 5584350, 93038},
 {"Info3598859911-8864466", 5584461, 93041},
 {"Info3598857435-2171160", 5584572, 93044}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 96, 1, 29, "Input"],
Cell[678, 25, 1936, 27, 249, "Print",
 CellTags->"Info3598858993-9948643"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2651, 57, 96, 1, 29, "Input"],
Cell[2750, 60, 1645, 23, 181, "Print",
 CellTags->"Info3598858995-9948643"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4432, 88, 103, 1, 29, "Input"],
Cell[4538, 91, 1525, 22, 194, "Print",
 CellTags->"Info3598859911-8864466"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6100, 118, 93, 1, 29, "Input"],
Cell[6196, 121, 1266, 18, 131, "Print",
 CellTags->"Info3598857435-2171160"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7499, 144, 102, 1, 29, "Input"],
Cell[7604, 147, 959, 23, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8600, 175, 125, 3, 80, "Section"],
Cell[CellGroupData[{
Cell[8750, 182, 3471, 49, 59, "Input"],
Cell[12224, 233, 1999, 53, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14260, 291, 2238, 35, 104, "Input"],
Cell[16501, 328, 1418964, 23565, 1012, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1435514, 23899, 158, 4, 80, "Section"],
Cell[CellGroupData[{
Cell[1435697, 23907, 2574, 39, 119, "Input"],
Cell[1438274, 23948, 1419767, 23585, 1012, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2858090, 47539, 251, 5, 80, "Section"],
Cell[CellGroupData[{
Cell[2858366, 47548, 126, 3, 29, "Input"],
Cell[2858495, 47553, 127, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2858659, 47561, 128, 3, 29, "Input"],
Cell[2858790, 47566, 72, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2858899, 47572, 3740, 53, 59, "Input"],
Cell[2862642, 47627, 2492, 66, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2865171, 47698, 2024, 31, 89, "Input"],
Cell[2867198, 47731, 897510, 14914, 1012, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3764757, 62651, 326, 6, 80, "Section"],
Cell[CellGroupData[{
Cell[3765108, 62661, 126, 3, 29, "Input"],
Cell[3765237, 62666, 127, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3765401, 62674, 128, 3, 29, "Input"],
Cell[3765532, 62679, 72, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3765641, 62685, 102, 1, 29, "Input"],
Cell[3765746, 62688, 1137, 28, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3766920, 62721, 3843, 55, 59, "Input"],
Cell[3770766, 62778, 2692, 69, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3773495, 62852, 2024, 31, 89, "Input"],
Cell[3775522, 62885, 897781, 14920, 1012, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4673352, 77811, 426, 8, 80, "Section"],
Cell[CellGroupData[{
Cell[4673803, 77823, 126, 3, 29, "Input"],
Cell[4673932, 77828, 127, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4674096, 77836, 128, 3, 29, "Input"],
Cell[4674227, 77841, 72, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4674336, 77847, 102, 1, 29, "Input"],
Cell[4674441, 77850, 1137, 28, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4675615, 77883, 4018, 57, 59, "Input"],
Cell[4679636, 77942, 2910, 74, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4682583, 78021, 2139, 33, 89, "Input"],
Cell[4684725, 78056, 899144, 14963, 1012, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
